"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .amountdecimal import AmountDecimal, AmountDecimalTypedDict
from moovio_sdk.types import BaseModel
from typing_extensions import TypedDict


class BillingCountAndAmountTypedDict(TypedDict):
    count: int
    r"""The number of items."""
    amount: AmountDecimalTypedDict
    r"""The total amount."""


class BillingCountAndAmount(BaseModel):
    count: int
    r"""The number of items."""

    amount: AmountDecimal
    r"""The total amount."""
