"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
import httpx
from moovio_sdk.models.components import (
    imagemetadatavalidationerror as components_imagemetadatavalidationerror,
)
from moovio_sdk.models.errors import MoovError
from moovio_sdk.types import BaseModel
from typing import Optional


class ImageRequestValidationErrorData(BaseModel):
    image: Optional[str] = None
    metadata: Optional[
        components_imagemetadatavalidationerror.ImageMetadataValidationError
    ] = None


@dataclass(unsafe_hash=True)
class ImageRequestValidationError(MoovError):
    data: ImageRequestValidationErrorData = field(hash=False)

    def __init__(
        self,
        data: ImageRequestValidationErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)
