"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class BankAccountWaitFor(str, Enum):
    PAYMENT_METHOD = "payment-method"
    RAIL_RESPONSE = "rail-response"
