"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class TransferFailureReason(str, Enum):
    r"""Reason for a transfer's failure."""

    SOURCE_PAYMENT_ERROR = "source-payment-error"
    DESTINATION_PAYMENT_ERROR = "destination-payment-error"
    WALLET_INSUFFICIENT_FUNDS = "wallet-insufficient-funds"
    REJECTED_HIGH_RISK = "rejected-high-risk"
    PROCESSING_ERROR = "processing-error"
