"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .bankaccountintegration import (
    BankAccountIntegration,
    BankAccountIntegrationTypedDict,
)
from moovio_sdk.types import BaseModel
from typing_extensions import TypedDict


class BankAccountPayloadTypedDict(TypedDict):
    r"""Describes the bank account to link to the Moov account."""

    account: BankAccountIntegrationTypedDict


class BankAccountPayload(BaseModel):
    r"""Describes the bank account to link to the Moov account."""

    account: BankAccountIntegration
