"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class WalletTransactionSourceType(str, Enum):
    TRANSFER = "transfer"
    DISPUTE = "dispute"
    ISSUING_CARD_TRANSACTION = "issuing-card-transaction"
    ISSUING_AUTHORIZATION = "issuing-authorization"
    SWEEP = "sweep"
    ADJUSTMENT = "adjustment"
    FEE = "fee"
    RESIDUAL = "residual"
