"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class DisputePhase(str, Enum):
    r"""The phase of a dispute within the dispute lifecycle."""

    PRE_DISPUTE = "pre-dispute"
    INQUIRY = "inquiry"
    CHARGEBACK = "chargeback"
    UNKNOWN = "unknown"
