"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class EntryMode(str, Enum):
    r"""How the card information was entered into the point of sale terminal."""

    CONTACTLESS = "contactless"
