"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class IssuedCardFormFactor(str, Enum):
    r"""Specifies the type of spend card to be issued. Presently supports virtual only, providing a digital number without a physical card."""

    VIRTUAL = "virtual"
