"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .achparticipant import AchParticipant, AchParticipantTypedDict
from moovio_sdk.types import BaseModel
import pydantic
from typing import List
from typing_extensions import Annotated, TypedDict


class FinancialInstitutionsTypedDict(TypedDict):
    ach_participants: List[AchParticipantTypedDict]


class FinancialInstitutions(BaseModel):
    ach_participants: Annotated[
        List[AchParticipant], pydantic.Field(alias="achParticipants")
    ]


try:
    FinancialInstitutions.model_rebuild()
except NameError:
    pass
