"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class InstantBankNetwork(str, Enum):
    r"""The network that the transaction was processed on."""

    FEDNOW = "fednow"
    RTP = "rtp"
