"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class DisputeStatus(str, Enum):
    r"""The status of a particular dispute.

    Read our [disputes guide](https://docs.moov.io/guides/money-movement/accept-payments/card-acceptance/disputes/#dispute-statuses) to learn what each status means.
    """

    RESPONSE_NEEDED = "response-needed"
    RESOLVED = "resolved"
    UNDER_REVIEW = "under-review"
    CLOSED = "closed"
    ACCEPTED = "accepted"
    EXPIRED = "expired"
    WON = "won"
    LOST = "lost"
