"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .asynccreatedrefund import AsyncCreatedRefund, AsyncCreatedRefundTypedDict
from .cardacquiringrefund import CardAcquiringRefund, CardAcquiringRefundTypedDict
from typing import Union
from typing_extensions import TypeAliasType


CreateRefundResponseTypedDict = TypeAliasType(
    "CreateRefundResponseTypedDict",
    Union[AsyncCreatedRefundTypedDict, CardAcquiringRefundTypedDict],
)


CreateRefundResponse = TypeAliasType(
    "CreateRefundResponse", Union[AsyncCreatedRefund, CardAcquiringRefund]
)
