"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class CardIssuingNetwork(str, Enum):
    r"""The name of the network a card transaction is routed through."""

    DISCOVER = "discover"
    SHAZAM = "shazam"
    VISA = "visa"
