"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .bankaccountexception import BankAccountException, BankAccountExceptionTypedDict
from .bankaccountstatus import BankAccountStatus
from .bankaccountstatusreason import BankAccountStatusReason
from moovio_sdk.types import BaseModel, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class WebhookDataBankAccountUpdatedTypedDict(TypedDict):
    bank_account_id: str
    account_id: str
    status: BankAccountStatus
    status_reason: BankAccountStatusReason
    r"""The reason the bank account status changed to the current value."""
    exception_details: NotRequired[BankAccountExceptionTypedDict]
    r"""Reason for, and details related to, an `errored` or `verificationFailed` bank account status."""


class WebhookDataBankAccountUpdated(BaseModel):
    bank_account_id: Annotated[str, pydantic.Field(alias="bankAccountID")]

    account_id: Annotated[str, pydantic.Field(alias="accountID")]

    status: BankAccountStatus

    status_reason: Annotated[
        BankAccountStatusReason, pydantic.Field(alias="statusReason")
    ]
    r"""The reason the bank account status changed to the current value."""

    exception_details: Annotated[
        Optional[BankAccountException], pydantic.Field(alias="exceptionDetails")
    ] = None
    r"""Reason for, and details related to, an `errored` or `verificationFailed` bank account status."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["exceptionDetails"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    WebhookDataBankAccountUpdated.model_rebuild()
except NameError:
    pass
