"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .microdepositstatus import MicroDepositStatus
from moovio_sdk.types import BaseModel
from typing_extensions import TypedDict


class CompletedMicroDepositsTypedDict(TypedDict):
    status: MicroDepositStatus


class CompletedMicroDeposits(BaseModel):
    status: MicroDepositStatus
