"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .applepayresponse import ApplePayResponse, ApplePayResponseTypedDict
from enum import Enum
from moovio_sdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class ApplePayTransferPaymentMethodPaymentMethodType(str, Enum):
    APPLE_PAY = "apple-pay"


class ApplePayTransferPaymentMethodTypedDict(TypedDict):
    payment_method_id: str
    r"""ID of the payment method."""
    payment_method_type: ApplePayTransferPaymentMethodPaymentMethodType
    apple_pay: ApplePayResponseTypedDict
    r"""Describes an Apple Pay token on a Moov account."""


class ApplePayTransferPaymentMethod(BaseModel):
    payment_method_id: Annotated[str, pydantic.Field(alias="paymentMethodID")]
    r"""ID of the payment method."""

    payment_method_type: Annotated[
        ApplePayTransferPaymentMethodPaymentMethodType,
        pydantic.Field(alias="paymentMethodType"),
    ]

    apple_pay: Annotated[ApplePayResponse, pydantic.Field(alias="applePay")]
    r"""Describes an Apple Pay token on a Moov account."""


try:
    ApplePayTransferPaymentMethod.model_rebuild()
except NameError:
    pass
