"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel
from typing_extensions import TypedDict


class WebhookSecretTypedDict(TypedDict):
    r"""The secret used to verify webhook payloads."""

    secret: str
    r"""The secret key used to sign webhook payloads. Use this to verify the authenticity of incoming webhooks."""


class WebhookSecret(BaseModel):
    r"""The secret used to verify webhook payloads."""

    secret: str
    r"""The secret key used to sign webhook payloads. Use this to verify the authenticity of incoming webhooks."""
