"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class DocumentType(str, Enum):
    r"""Types of documents that can be uploaded."""

    DRIVERS_LICENSE = "driversLicense"
    PASSPORT = "passport"
    UTILITY_BILL = "utilityBill"
    BANK_STATEMENT = "bankStatement"
