"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .createscheduledtransferlineitem import (
    CreateScheduledTransferLineItem,
    CreateScheduledTransferLineItemTypedDict,
)
from moovio_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class CreateScheduledTransferLineItemsTypedDict(TypedDict):
    r"""An optional collection of line items for a scheduled transfer.
    When line items are provided their total must equal `amount` minus `salesTaxAmount`.
    """

    items: List[CreateScheduledTransferLineItemTypedDict]
    r"""The list of line items."""


class CreateScheduledTransferLineItems(BaseModel):
    r"""An optional collection of line items for a scheduled transfer.
    When line items are provided their total must equal `amount` minus `salesTaxAmount`.
    """

    items: List[CreateScheduledTransferLineItem]
    r"""The list of line items."""
