"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import Dict, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class PaymentLinkCustomerOptionsTypedDict(TypedDict):
    require_address: NotRequired[bool]
    r"""If true, a billing address is required when completing the payment form."""
    require_phone: NotRequired[bool]
    r"""If true, a phone number is required when completing the payment form."""
    metadata: NotRequired[Dict[str, str]]
    r"""Optional free-form metadata for the Moov account that will represent this customer."""


class PaymentLinkCustomerOptions(BaseModel):
    require_address: Annotated[
        Optional[bool], pydantic.Field(alias="requireAddress")
    ] = None
    r"""If true, a billing address is required when completing the payment form."""

    require_phone: Annotated[Optional[bool], pydantic.Field(alias="requirePhone")] = (
        None
    )
    r"""If true, a phone number is required when completing the payment form."""

    metadata: Optional[Dict[str, str]] = None
    r"""Optional free-form metadata for the Moov account that will represent this customer."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["requireAddress", "requirePhone", "metadata"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    PaymentLinkCustomerOptions.model_rebuild()
except NameError:
    pass
