"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class CallToAction(str, Enum):
    r"""The text to be displayed on web form's submit button.

    If set to \"auto\" the UI will automatically select between
    \"pay\" and \"confirm\" for payments and payouts respectively.
    """

    PAY = "pay"
    BOOK = "book"
    SUBSCRIBE = "subscribe"
    DONATE = "donate"
    CONFIRM = "confirm"
    AUTO = "auto"
