"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .webhookdatatransferstatus import WebhookDataTransferStatus
from .webhooktransferpaymentmethoddetails import (
    WebhookTransferPaymentMethodDetails,
    WebhookTransferPaymentMethodDetailsTypedDict,
)
from moovio_sdk.types import BaseModel, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class WebhookDataTransferUpdatedTypedDict(TypedDict):
    account_id: str
    r"""The accountID which facilitated the transfer."""
    transfer_id: str
    status: WebhookDataTransferStatus
    source: WebhookTransferPaymentMethodDetailsTypedDict
    r"""Payment method details for the source or destination of a transfer."""
    destination: WebhookTransferPaymentMethodDetailsTypedDict
    r"""Payment method details for the source or destination of a transfer."""
    foreign_id: NotRequired[str]


class WebhookDataTransferUpdated(BaseModel):
    account_id: Annotated[str, pydantic.Field(alias="accountID")]
    r"""The accountID which facilitated the transfer."""

    transfer_id: Annotated[str, pydantic.Field(alias="transferID")]

    status: WebhookDataTransferStatus

    source: WebhookTransferPaymentMethodDetails
    r"""Payment method details for the source or destination of a transfer."""

    destination: WebhookTransferPaymentMethodDetails
    r"""Payment method details for the source or destination of a transfer."""

    foreign_id: Annotated[Optional[str], pydantic.Field(alias="foreignID")] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["foreignID"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    WebhookDataTransferUpdated.model_rebuild()
except NameError:
    pass
