"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
import httpx
from moovio_sdk.models.errors import MoovError
from moovio_sdk.types import BaseModel
import pydantic
from typing import Optional
from typing_extensions import Annotated


class ListTransfersValidationErrorData(BaseModel):
    account_i_ds: Annotated[Optional[str], pydantic.Field(alias="accountIDs")] = None
    status: Optional[str] = None
    start_date_time: Annotated[Optional[str], pydantic.Field(alias="startDateTime")] = (
        None
    )
    end_date_time: Annotated[Optional[str], pydantic.Field(alias="endDateTime")] = None
    skip: Optional[str] = None
    count: Optional[str] = None
    group_id: Annotated[Optional[str], pydantic.Field(alias="groupID")] = None
    foreign_id: Annotated[Optional[str], pydantic.Field(alias="foreignID")] = None
    schedule_id: Annotated[Optional[str], pydantic.Field(alias="scheduleID")] = None
    payment_link_code: Annotated[
        Optional[str], pydantic.Field(alias="paymentLinkCode")
    ] = None
    refunded: Optional[str] = None
    disputed: Optional[str] = None


@dataclass(unsafe_hash=True)
class ListTransfersValidationError(MoovError):
    data: ListTransfersValidationErrorData = field(hash=False)

    def __init__(
        self,
        data: ListTransfersValidationErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)
