"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class RTPRejectionCode(str, Enum):
    r"""The rejection code of an RTP transaction that caused the bank account status to change.

    - AC03: Account Invalid
    - AC04: Account Closed
    - AC06: Account Blocked
    - AC14: Creditor Account Type Invalid
    - AG01: Transactions Forbidden On Account
    - AG03: Transaction Type Not Supported
    - MD07: Customer Deceased
    """

    AC03 = "AC03"
    AC04 = "AC04"
    AC06 = "AC06"
    AC14 = "AC14"
    AG01 = "AG01"
    AG03 = "AG03"
    MD07 = "MD07"
