"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .sendfundsach import SendFundsAch, SendFundsAchTypedDict
from .sendfundsinstantbank import SendFundsInstantBank, SendFundsInstantBankTypedDict
from .sendfundspushtocard import SendFundsPushToCard, SendFundsPushToCardTypedDict
from .sendfundsrtp import SendFundsRtp, SendFundsRtpTypedDict
from moovio_sdk.types import BaseModel, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class SendFundsTypedDict(TypedDict):
    ach: NotRequired[SendFundsAchTypedDict]
    push_to_card: NotRequired[SendFundsPushToCardTypedDict]
    rtp: NotRequired[SendFundsRtpTypedDict]
    instant_bank: NotRequired[SendFundsInstantBankTypedDict]


class SendFunds(BaseModel):
    ach: Optional[SendFundsAch] = None

    push_to_card: Annotated[
        Optional[SendFundsPushToCard], pydantic.Field(alias="pushToCard")
    ] = None

    rtp: Optional[SendFundsRtp] = None

    instant_bank: Annotated[
        Optional[SendFundsInstantBank], pydantic.Field(alias="instantBank")
    ] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["ach", "pushToCard", "rtp", "instantBank"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    SendFunds.model_rebuild()
except NameError:
    pass
