"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .manualtermsofservice import ManualTermsOfService, ManualTermsOfServiceTypedDict
from moovio_sdk.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class TermsOfServicePayloadTypedDict(TypedDict):
    token: NotRequired[str]
    manual: NotRequired[ManualTermsOfServiceTypedDict]
    r"""Describes the acceptance of the Terms of Service. All data is required, and must be from the user."""


class TermsOfServicePayload(BaseModel):
    token: Optional[str] = None

    manual: Optional[ManualTermsOfService] = None
    r"""Describes the acceptance of the Terms of Service. All data is required, and must be from the user."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["token", "manual"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
