"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ACHTransactionStatus(str, Enum):
    r"""Status of a transaction within the ACH lifecycle."""

    UNKNOWN = ""
    INITIATED = "initiated"
    ORIGINATED = "originated"
    CORRECTED = "corrected"
    RETURNED = "returned"
    COMPLETED = "completed"
    CANCELED = "canceled"
