"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class PaymentLinkType(str, Enum):
    PAYMENT = "payment"
    PAYOUT = "payout"
    INVOICE_PAYMENT = "invoice-payment"
