"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class TerminalApplicationStatus(str, Enum):
    r"""Status of the terminal application."""

    UNDEFINED = "undefined"
    PENDING = "pending"
    ENABLED = "enabled"
    DISABLED = "disabled"
