"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ReturnPolicyType(str, Enum):
    NONE = "none"
    EXCHANGE_ONLY = "exchangeOnly"
    WITHIN_THIRTY_DAYS = "withinThirtyDays"
    OTHER = "other"
