"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .refundstatus import RefundStatus
from moovio_sdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class WebhookDataRefundUpdatedTypedDict(TypedDict):
    account_id: str
    transfer_id: str
    refund_id: str
    status: RefundStatus


class WebhookDataRefundUpdated(BaseModel):
    account_id: Annotated[str, pydantic.Field(alias="accountID")]

    transfer_id: Annotated[str, pydantic.Field(alias="transferID")]

    refund_id: Annotated[str, pydantic.Field(alias="refundID")]

    status: RefundStatus


try:
    WebhookDataRefundUpdated.model_rebuild()
except NameError:
    pass
