"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .occurrence import Occurrence, OccurrenceTypedDict
from .recur import Recur, RecurTypedDict
from moovio_sdk.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class UpsertScheduleTypedDict(TypedDict):
    description: NotRequired[str]
    r"""Simple description of what the schedule is."""
    occurrences: NotRequired[List[OccurrenceTypedDict]]
    recur: NotRequired[RecurTypedDict]
    r"""Defines configuration for recurring transfers."""


class UpsertSchedule(BaseModel):
    description: Optional[str] = None
    r"""Simple description of what the schedule is."""

    occurrences: Optional[List[Occurrence]] = None

    recur: Optional[Recur] = None
    r"""Defines configuration for recurring transfers."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["description", "occurrences", "recur"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
