"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class RequirementID(str, Enum):
    r"""The unique ID of what the requirement is asking to be filled out."""

    ACCOUNT_TOS_ACCEPTANCE = "account.tos-acceptance"
    INDIVIDUAL_MOBILE = "individual.mobile"
    INDIVIDUAL_EMAIL = "individual.email"
    INDIVIDUAL_EMAIL_OR_MOBILE = "individual.email-or-mobile"
    INDIVIDUAL_FIRSTNAME = "individual.firstname"
    INDIVIDUAL_LASTNAME = "individual.lastname"
    INDIVIDUAL_ADDRESS = "individual.address"
    INDIVIDUAL_SSN_LAST4 = "individual.ssn-last4"
    INDIVIDUAL_SSN = "individual.ssn"
    INDIVIDUAL_BIRTHDATE = "individual.birthdate"
    BUSINESS_LEGALNAME = "business.legalname"
    BUSINESS_DESCRIPTION_OR_WEBSITE = "business.description-or-website"
    BUSINESS_ENTITY_TYPE = "business.entity-type"
    BUSINESS_BUSINESS_TYPE = "business.business-type"
    BUSINESS_DBA = "business.dba"
    BUSINESS_EIN = "business.ein"
    BUSINESS_ADDRESS = "business.address"
    BUSINESS_PHONE = "business.phone"
    BUSINESS_ADMINS = "business.admins"
    BUSINESS_CONTROLLERS = "business.controllers"
    BUSINESS_OWNERS = "business.owners"
    BUSINESS_CLASSIFICATION = "business.classification"
    BUSINESS_INDUSTRY_CODE_MCC = "business.industry-code-mcc"
    BUSINESS_INDUSTRY = "business.industry"
    BUSINESS_INDICATE_OWNERS_PROVIDED = "business.indicate-owners-provided"
    BUSINESS_AVERAGE_TRANSACTION_SIZE = "business.average-transaction-size"
    BUSINESS_MAX_TRANSACTION_SIZE = "business.max-transaction-size"
    BUSINESS_AVERAGE_MONTHLY_TRANSACTION_VOLUME = (
        "business.average-monthly-transaction-volume"
    )
    BUSINESS_VOLUME_BY_CUSTOMER_TYPE = "business.volume-by-customer-type"
    BUSINESS_CARD_VOLUME_DISTRIBUTION = "business.card-volume-distribution"
    BUSINESS_FULFILLMENT = "business.fulfillment"
    BUSINESS_DESCRIPTION = "business.description"
    BUSINESS_UNDERWRITING_DOCUMENTS_TIER_ONE = (
        "business.underwriting-documents-tier-one"
    )
    BANK_ACCOUNTS_NAME = "bank-accounts.name"
    BANK_ACCOUNTS_ROUTING_NUMBER = "bank-accounts.routing-number"
    BANK_ACCOUNTS_ACCOUNT_NUMBER = "bank-accounts.account-number"
    DOCUMENT_BUSINESS_VERIFICATION = "document.business.verification"
    DOCUMENT_INDIVIDUAL_TIN = "document.individual.tin"
    DOCUMENT_INDIVIDUAL_VERIFICATION = "document.individual.verification"
    DOCUMENT_REPRESENTATIVE_REP_UUID_TIN = "document.representative.{rep-uuid}.tin"
    DOCUMENT_REPRESENTATIVE_REP_UUID_VERIFICATION = (
        "document.representative.{rep-uuid}.verification"
    )
    REPRESENTATIVE_REP_UUID_MOBILE = "representative.{rep-uuid}.mobile"
    REPRESENTATIVE_REP_UUID_EMAIL = "representative.{rep-uuid}.email"
    REPRESENTATIVE_REP_UUID_EMAIL_OR_MOBILE = (
        "representative.{rep-uuid}.email-or-mobile"
    )
    REPRESENTATIVE_REP_UUID_FIRSTNAME = "representative.{rep-uuid}.firstname"
    REPRESENTATIVE_REP_UUID_LASTNAME = "representative.{rep-uuid}.lastname"
    REPRESENTATIVE_REP_UUID_ADDRESS = "representative.{rep-uuid}.address"
    REPRESENTATIVE_REP_UUID_SSN_LAST4 = "representative.{rep-uuid}.ssn-last4"
    REPRESENTATIVE_REP_UUID_SSN = "representative.{rep-uuid}.ssn"
    REPRESENTATIVE_REP_UUID_BIRTHDATE = "representative.{rep-uuid}.birthdate"
    REPRESENTATIVE_REP_UUID_JOB_TITLE = "representative.{rep-uuid}.job-title"
    REPRESENTATIVE_REP_UUID_IS_CONTROLLER = "representative.{rep-uuid}.is-controller"
    REPRESENTATIVE_REP_UUID_IS_OWNER = "representative.{rep-uuid}.is-owner"
    REPRESENTATIVE_REP_UUID_OWNERSHIP = "representative.{rep-uuid}.ownership"
    DOCUMENT_DOC_UUID_ = "document.{doc-uuid}"
    UNDERWRITING_BUSINESS_PRESENCE = "underwriting.businessPresence"
    UNDERWRITING_GEOGRAPHIC_REACH = "underwriting.geographicReach"
    UNDERWRITING_VOLUME_SHARE_BY_CUSTOMER_TYPE = (
        "underwriting.volumeShareByCustomerType"
    )
    UNDERWRITING_PENDING_LITIGATION = "underwriting.pendingLitigation"
    UNDERWRITING_DOCUMENTS_PROCESSING_STATEMENTS_PAST3_MONTHS = (
        "underwriting.documents.processingStatementsPast3Months"
    )
    UNDERWRITING_COLLECT_FUNDS_CARD_PAYMENTS_CARD_ACCEPTANCE_METHODS = (
        "underwriting.collectFunds.cardPayments.cardAcceptanceMethods"
    )
    UNDERWRITING_COLLECT_FUNDS_CARD_PAYMENTS_CURRENTLY_ACCEPTS_CARDS = (
        "underwriting.collectFunds.cardPayments.currentlyAcceptsCards"
    )
    UNDERWRITING_COLLECT_FUNDS_CARD_PAYMENTS_ESTIMATED_ACTIVITY_AVERAGE_TRANSACTION_AMOUNT = "underwriting.collectFunds.cardPayments.estimatedActivity.averageTransactionAmount"
    UNDERWRITING_COLLECT_FUNDS_CARD_PAYMENTS_ESTIMATED_ACTIVITY_MAXIMUM_TRANSACTION_AMOUNT = "underwriting.collectFunds.cardPayments.estimatedActivity.maximumTransactionAmount"
    UNDERWRITING_COLLECT_FUNDS_CARD_PAYMENTS_ESTIMATED_ACTIVITY_MONTHLY_VOLUME_RANGE = (
        "underwriting.collectFunds.cardPayments.estimatedActivity.monthlyVolumeRange"
    )
    UNDERWRITING_COLLECT_FUNDS_CARD_PAYMENTS_FULFILLMENT = (
        "underwriting.collectFunds.cardPayments.fulfillment"
    )
    UNDERWRITING_COLLECT_FUNDS_CARD_PAYMENTS_REFUND_POLICY = (
        "underwriting.collectFunds.cardPayments.refundPolicy"
    )
    UNDERWRITING_COLLECT_FUNDS_ACH_CARD_ACCEPTANCE_METHODS = (
        "underwriting.collectFunds.ach.cardAcceptanceMethods"
    )
    UNDERWRITING_COLLECT_FUNDS_ACH_CURRENTLY_ACCEPTS_CARDS = (
        "underwriting.collectFunds.ach.currentlyAcceptsCards"
    )
    UNDERWRITING_COLLECT_FUNDS_ACH_ESTIMATED_ACTIVITY_AVERAGE_TRANSACTION_AMOUNT = (
        "underwriting.collectFunds.ach.estimatedActivity.averageTransactionAmount"
    )
    UNDERWRITING_COLLECT_FUNDS_ACH_ESTIMATED_ACTIVITY_MAXIMUM_TRANSACTION_AMOUNT = (
        "underwriting.collectFunds.ach.estimatedActivity.maximumTransactionAmount"
    )
    UNDERWRITING_COLLECT_FUNDS_ACH_ESTIMATED_ACTIVITY_MONTHLY_VOLUME_RANGE = (
        "underwriting.collectFunds.ach.estimatedActivity.monthlyVolumeRange"
    )
    UNDERWRITING_COLLECT_FUNDS_ACH_FULFILLMENT = (
        "underwriting.collectFunds.ach.fulfillment"
    )
    UNDERWRITING_COLLECT_FUNDS_ACH_REFUND_POLICY = (
        "underwriting.collectFunds.ach.refundPolicy"
    )
    UNDERWRITING_SEND_FUNDS_ACH_CARD_ACCEPTANCE_METHODS = (
        "underwriting.sendFunds.ach.cardAcceptanceMethods"
    )
    UNDERWRITING_SEND_FUNDS_ACH_CURRENTLY_ACCEPTS_CARDS = (
        "underwriting.sendFunds.ach.currentlyAcceptsCards"
    )
    UNDERWRITING_SEND_FUNDS_ACH_ESTIMATED_ACTIVITY_AVERAGE_TRANSACTION_AMOUNT = (
        "underwriting.sendFunds.ach.estimatedActivity.averageTransactionAmount"
    )
    UNDERWRITING_SEND_FUNDS_ACH_ESTIMATED_ACTIVITY_MAXIMUM_TRANSACTION_AMOUNT = (
        "underwriting.sendFunds.ach.estimatedActivity.maximumTransactionAmount"
    )
    UNDERWRITING_SEND_FUNDS_ACH_ESTIMATED_ACTIVITY_MONTHLY_VOLUME_RANGE = (
        "underwriting.sendFunds.ach.estimatedActivity.monthlyVolumeRange"
    )
    UNDERWRITING_SEND_FUNDS_ACH_FULFILLMENT = "underwriting.sendFunds.ach.fulfillment"
    UNDERWRITING_SEND_FUNDS_ACH_REFUND_POLICY = (
        "underwriting.sendFunds.ach.refundPolicy"
    )
    UNDERWRITING_SEND_FUNDS_RTP_CARD_ACCEPTANCE_METHODS = (
        "underwriting.sendFunds.rtp.cardAcceptanceMethods"
    )
    UNDERWRITING_SEND_FUNDS_RTP_CURRENTLY_ACCEPTS_CARDS = (
        "underwriting.sendFunds.rtp.currentlyAcceptsCards"
    )
    UNDERWRITING_SEND_FUNDS_RTP_ESTIMATED_ACTIVITY_AVERAGE_TRANSACTION_AMOUNT = (
        "underwriting.sendFunds.rtp.estimatedActivity.averageTransactionAmount"
    )
    UNDERWRITING_SEND_FUNDS_RTP_ESTIMATED_ACTIVITY_MAXIMUM_TRANSACTION_AMOUNT = (
        "underwriting.sendFunds.rtp.estimatedActivity.maximumTransactionAmount"
    )
    UNDERWRITING_SEND_FUNDS_RTP_ESTIMATED_ACTIVITY_MONTHLY_VOLUME_RANGE = (
        "underwriting.sendFunds.rtp.estimatedActivity.monthlyVolumeRange"
    )
    UNDERWRITING_SEND_FUNDS_RTP_FULFILLMENT = "underwriting.sendFunds.rtp.fulfillment"
    UNDERWRITING_SEND_FUNDS_RTP_REFUND_POLICY = (
        "underwriting.sendFunds.rtp.refundPolicy"
    )
    UNDERWRITING_SEND_FUNDS_PUSH_TO_CARD_CARD_ACCEPTANCE_METHODS = (
        "underwriting.sendFunds.pushToCard.cardAcceptanceMethods"
    )
    UNDERWRITING_SEND_FUNDS_PUSH_TO_CARD_CURRENTLY_ACCEPTS_CARDS = (
        "underwriting.sendFunds.pushToCard.currentlyAcceptsCards"
    )
    UNDERWRITING_SEND_FUNDS_PUSH_TO_CARD_ESTIMATED_ACTIVITY_AVERAGE_TRANSACTION_AMOUNT = "underwriting.sendFunds.pushToCard.estimatedActivity.averageTransactionAmount"
    UNDERWRITING_SEND_FUNDS_PUSH_TO_CARD_ESTIMATED_ACTIVITY_MAXIMUM_TRANSACTION_AMOUNT = "underwriting.sendFunds.pushToCard.estimatedActivity.maximumTransactionAmount"
    UNDERWRITING_SEND_FUNDS_PUSH_TO_CARD_ESTIMATED_ACTIVITY_MONTHLY_VOLUME_RANGE = (
        "underwriting.sendFunds.pushToCard.estimatedActivity.monthlyVolumeRange"
    )
    UNDERWRITING_SEND_FUNDS_PUSH_TO_CARD_FULFILLMENT = (
        "underwriting.sendFunds.pushToCard.fulfillment"
    )
    UNDERWRITING_SEND_FUNDS_PUSH_TO_CARD_REFUND_POLICY = (
        "underwriting.sendFunds.pushToCard.refundPolicy"
    )
    UNDERWRITING_MONEY_TRANSFER_PULL_FROM_CARD_CARD_ACCEPTANCE_METHODS = (
        "underwriting.moneyTransfer.pullFromCard.cardAcceptanceMethods"
    )
    UNDERWRITING_MONEY_TRANSFER_PULL_FROM_CARD_CURRENTLY_ACCEPTS_CARDS = (
        "underwriting.moneyTransfer.pullFromCard.currentlyAcceptsCards"
    )
    UNDERWRITING_MONEY_TRANSFER_PULL_FROM_CARD_ESTIMATED_ACTIVITY_AVERAGE_TRANSACTION_AMOUNT = "underwriting.moneyTransfer.pullFromCard.estimatedActivity.averageTransactionAmount"
    UNDERWRITING_MONEY_TRANSFER_PULL_FROM_CARD_ESTIMATED_ACTIVITY_MAXIMUM_TRANSACTION_AMOUNT = "underwriting.moneyTransfer.pullFromCard.estimatedActivity.maximumTransactionAmount"
    UNDERWRITING_MONEY_TRANSFER_PULL_FROM_CARD_ESTIMATED_ACTIVITY_MONTHLY_VOLUME_RANGE = "underwriting.moneyTransfer.pullFromCard.estimatedActivity.monthlyVolumeRange"
    UNDERWRITING_MONEY_TRANSFER_PULL_FROM_CARD_FULFILLMENT = (
        "underwriting.moneyTransfer.pullFromCard.fulfillment"
    )
    UNDERWRITING_MONEY_TRANSFER_PULL_FROM_CARD_REFUND_POLICY = (
        "underwriting.moneyTransfer.pullFromCard.refundPolicy"
    )
    UNDERWRITING_MONEY_TRANSFER_PUSH_TO_CARD_CARD_ACCEPTANCE_METHODS = (
        "underwriting.moneyTransfer.pushToCard.cardAcceptanceMethods"
    )
    UNDERWRITING_MONEY_TRANSFER_PUSH_TO_CARD_CURRENTLY_ACCEPTS_CARDS = (
        "underwriting.moneyTransfer.pushToCard.currentlyAcceptsCards"
    )
    UNDERWRITING_MONEY_TRANSFER_PUSH_TO_CARD_ESTIMATED_ACTIVITY_AVERAGE_TRANSACTION_AMOUNT = "underwriting.moneyTransfer.pushToCard.estimatedActivity.averageTransactionAmount"
    UNDERWRITING_MONEY_TRANSFER_PUSH_TO_CARD_ESTIMATED_ACTIVITY_MAXIMUM_TRANSACTION_AMOUNT = "underwriting.moneyTransfer.pushToCard.estimatedActivity.maximumTransactionAmount"
    UNDERWRITING_MONEY_TRANSFER_PUSH_TO_CARD_ESTIMATED_ACTIVITY_MONTHLY_VOLUME_RANGE = (
        "underwriting.moneyTransfer.pushToCard.estimatedActivity.monthlyVolumeRange"
    )
    UNDERWRITING_MONEY_TRANSFER_PUSH_TO_CARD_FULFILLMENT = (
        "underwriting.moneyTransfer.pushToCard.fulfillment"
    )
    UNDERWRITING_MONEY_TRANSFER_PUSH_TO_CARD_REFUND_POLICY = (
        "underwriting.moneyTransfer.pushToCard.refundPolicy"
    )
