"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel
from typing_extensions import TypedDict


class CreateReversalTypedDict(TypedDict):
    amount: int
    r"""Amount to reverse in cents. Partial amounts will automatically trigger a refund instead of a cancellation."""


class CreateReversal(BaseModel):
    amount: int
    r"""Amount to reverse in cents. Partial amounts will automatically trigger a refund instead of a cancellation."""
