"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class BusinessPresence(str, Enum):
    COMMERCIAL_OFFICE = "commercial-office"
    HOME_BASED = "home-based"
    MIXED_PRESENCE = "mixed-presence"
    MOBILE_BUSINESS = "mobile-business"
    ONLINE_ONLY = "online-only"
    RETAIL_STOREFRONT = "retail-storefront"
