"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class OccurrenceStatus(str, Enum):
    r"""Status of the completed occurrence."""

    PENDING = "pending"
    FAILED = "failed"
    COMPLETED = "completed"
