"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .address import Address, AddressTypedDict
from .birthdate import BirthDate, BirthDateTypedDict
from .governmentid import GovernmentID, GovernmentIDTypedDict
from .individualname import IndividualName, IndividualNameTypedDict
from .phonenumber import PhoneNumber, PhoneNumberTypedDict
from moovio_sdk.types import BaseModel, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class CreateIndividualProfileTypedDict(TypedDict):
    name: IndividualNameTypedDict
    phone: NotRequired[PhoneNumberTypedDict]
    email: NotRequired[str]
    address: NotRequired[AddressTypedDict]
    birth_date: NotRequired[BirthDateTypedDict]
    government_id: NotRequired[GovernmentIDTypedDict]


class CreateIndividualProfile(BaseModel):
    name: IndividualName

    phone: Optional[PhoneNumber] = None

    email: Optional[str] = None

    address: Optional[Address] = None

    birth_date: Annotated[Optional[BirthDate], pydantic.Field(alias="birthDate")] = None

    government_id: Annotated[
        Optional[GovernmentID], pydantic.Field(alias="governmentID")
    ] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            ["phone", "email", "address", "birthDate", "governmentID"]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    CreateIndividualProfile.model_rebuild()
except NameError:
    pass
