"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .amount import Amount, AmountTypedDict
from datetime import datetime
from moovio_sdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class AsyncCreatedRefundTypedDict(TypedDict):
    r"""Asynchronous refund response"""

    refund_id: str
    created_on: datetime
    amount: AmountTypedDict


class AsyncCreatedRefund(BaseModel):
    r"""Asynchronous refund response"""

    refund_id: Annotated[str, pydantic.Field(alias="refundID")]

    created_on: Annotated[datetime, pydantic.Field(alias="createdOn")]

    amount: Amount


try:
    AsyncCreatedRefund.model_rebuild()
except NameError:
    pass
