"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class PrimaryRegulator(str, Enum):
    r"""If the business is a financial institution, this field describes its primary regulator."""

    OCC = "OCC"
    FDIC = "FDIC"
    NCUA = "NCUA"
    FRB = "FRB"
    STATE_CU_REGULATOR = "state-cu-regulator"
