"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
import httpx
from moovio_sdk.models.components import (
    createauthorizedusererror as components_createauthorizedusererror,
)
from moovio_sdk.models.errors import MoovError
from moovio_sdk.types import BaseModel
import pydantic
from typing import Optional
from typing_extensions import Annotated


class UpdateIssuedCardErrorData(BaseModel):
    state: Optional[str] = None
    memo: Optional[str] = None
    authorized_user: Annotated[
        Optional[components_createauthorizedusererror.CreateAuthorizedUserError],
        pydantic.Field(alias="authorizedUser"),
    ] = None


@dataclass(unsafe_hash=True)
class UpdateIssuedCardError(MoovError):
    data: UpdateIssuedCardErrorData = field(hash=False)

    def __init__(
        self,
        data: UpdateIssuedCardErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)
