"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
import httpx
from moovio_sdk.models.errors import MoovError
from moovio_sdk.types import BaseModel
import pydantic
from typing import Dict, Optional
from typing_extensions import Annotated


class OnboardingInviteErrorData(BaseModel):
    return_url: Annotated[Optional[str], pydantic.Field(alias="returnURL")] = None
    terms_of_service_url: Annotated[
        Optional[str], pydantic.Field(alias="termsOfServiceURL")
    ] = None
    scopes: Optional[Dict[str, str]] = None
    capabilities: Optional[Dict[str, str]] = None
    fee_plan_codes: Annotated[
        Optional[Dict[str, str]], pydantic.Field(alias="feePlanCodes")
    ] = None


@dataclass(unsafe_hash=True)
class OnboardingInviteError(MoovError):
    data: OnboardingInviteErrorData = field(hash=False)

    def __init__(
        self,
        data: OnboardingInviteErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)
