"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class FulfillmentTimeframe(str, Enum):
    IMMEDIATE = "immediate"
    OTHER = "other"
    OVER_30_DAYS = "over-30-days"
    PRE_ORDER = "pre-order"
    RECURRING_SCHEDULE = "recurring-schedule"
    SCHEDULED_EVENT = "scheduled-event"
    WITHIN_30_DAYS = "within-30-days"
    WITHIN_7_DAYS = "within-7-days"
