"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ReceiptKind(str, Enum):
    r"""The type of receipt being requested."""

    SALE_CUSTOMER_V1 = "sale.customer.v1"
