"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .createtransferdestinationach import (
    CreateTransferDestinationACH,
    CreateTransferDestinationACHTypedDict,
)
from .createtransferdestinationcard import (
    CreateTransferDestinationCard,
    CreateTransferDestinationCardTypedDict,
)
from moovio_sdk.types import BaseModel, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class CreateTransferDestinationTypedDict(TypedDict):
    r"""The final stage of a transfer and the ultimate recipient of the funds."""

    payment_method_id: str
    card_details: NotRequired[CreateTransferDestinationCardTypedDict]
    ach_details: NotRequired[CreateTransferDestinationACHTypedDict]


class CreateTransferDestination(BaseModel):
    r"""The final stage of a transfer and the ultimate recipient of the funds."""

    payment_method_id: Annotated[str, pydantic.Field(alias="paymentMethodID")]

    card_details: Annotated[
        Optional[CreateTransferDestinationCard], pydantic.Field(alias="cardDetails")
    ] = None

    ach_details: Annotated[
        Optional[CreateTransferDestinationACH], pydantic.Field(alias="achDetails")
    ] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["cardDetails", "achDetails"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    CreateTransferDestination.model_rebuild()
except NameError:
    pass
