"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class AssignProductImageTypedDict(TypedDict):
    image_id: str
    r"""Unique identifier for a product or product option image resource."""


class AssignProductImage(BaseModel):
    image_id: Annotated[str, pydantic.Field(alias="imageID")]
    r"""Unique identifier for a product or product option image resource."""


try:
    AssignProductImage.model_rebuild()
except NameError:
    pass
