"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .achinstitution import ACHInstitution, ACHInstitutionTypedDict
from .fednowinstitution import FedNowInstitution, FedNowInstitutionTypedDict
from .rtpinstitution import RTPInstitution, RTPInstitutionTypedDict
from .wireinstitution import WireInstitution, WireInstitutionTypedDict
from moovio_sdk.types import BaseModel, Nullable, UNSET_SENTINEL
from pydantic import model_serializer
from typing import List
from typing_extensions import TypedDict


class InstitutionsSearchResponseTypedDict(TypedDict):
    ach: Nullable[List[ACHInstitutionTypedDict]]
    rtp: Nullable[List[RTPInstitutionTypedDict]]
    wire: Nullable[List[WireInstitutionTypedDict]]
    fednow: Nullable[List[FedNowInstitutionTypedDict]]


class InstitutionsSearchResponse(BaseModel):
    ach: Nullable[List[ACHInstitution]]

    rtp: Nullable[List[RTPInstitution]]

    wire: Nullable[List[WireInstitution]]

    fednow: Nullable[List[FedNowInstitution]]

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                m[k] = val

        return m
