"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ManualTypedDict(TypedDict):
    accepted_date: NotRequired[str]
    accepted_domain: NotRequired[str]
    accepted_ip: NotRequired[str]
    accepted_user_agent: NotRequired[str]


class Manual(BaseModel):
    accepted_date: Annotated[Optional[str], pydantic.Field(alias="acceptedDate")] = None

    accepted_domain: Annotated[
        Optional[str], pydantic.Field(alias="acceptedDomain")
    ] = None

    accepted_ip: Annotated[Optional[str], pydantic.Field(alias="acceptedIP")] = None

    accepted_user_agent: Annotated[
        Optional[str], pydantic.Field(alias="acceptedUserAgent")
    ] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            ["acceptedDate", "acceptedDomain", "acceptedIP", "acceptedUserAgent"]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class TermsOfServiceErrorTypedDict(TypedDict):
    token: NotRequired[str]
    manual: NotRequired[ManualTypedDict]


class TermsOfServiceError(BaseModel):
    token: Optional[str] = None

    manual: Optional[Manual] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["token", "manual"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    Manual.model_rebuild()
except NameError:
    pass
