"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class GeographicReach(str, Enum):
    INTERNATIONAL_ONLY = "international-only"
    US_AND_INTERNATIONAL = "us-and-international"
    US_ONLY = "us-only"
