"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class TransferLineItemImageMetadataTypedDict(TypedDict):
    image_id: str
    r"""Unique identifier for a image resource."""
    link: str
    r"""The image's public URL."""
    public_id: str
    r"""A unique identifier for an image, used in public image links."""
    alt_text: NotRequired[str]
    r"""Alternative text for the image."""


class TransferLineItemImageMetadata(BaseModel):
    image_id: Annotated[str, pydantic.Field(alias="imageID")]
    r"""Unique identifier for a image resource."""

    link: str
    r"""The image's public URL."""

    public_id: Annotated[str, pydantic.Field(alias="publicID")]
    r"""A unique identifier for an image, used in public image links."""

    alt_text: Annotated[Optional[str], pydantic.Field(alias="altText")] = None
    r"""Alternative text for the image."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["altText"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    TransferLineItemImageMetadata.model_rebuild()
except NameError:
    pass
