"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class InstantBankFailureCode(str, Enum):
    r"""Status codes for instant-bank failures."""

    PROCESSING_ERROR = "processing-error"
    INVALID_ACCOUNT = "invalid-account"
    ACCOUNT_CLOSED = "account-closed"
    ACCOUNT_BLOCKED = "account-blocked"
    INVALID_FIELD = "invalid-field"
    TRANSACTION_NOT_SUPPORTED = "transaction-not-supported"
    LIMIT_EXCEEDED = "limit-exceeded"
    INVALID_AMOUNT = "invalid-amount"
    CUSTOMER_DECEASED = "customer-deceased"
    PARTICIPANT_NOT_AVAILABLE = "participant-not-available"
    OTHER = "other"
