"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class AuthorizedUserTypedDict(TypedDict):
    r"""Fields for identifying an authorized individual."""

    first_name: str
    last_name: str


class AuthorizedUser(BaseModel):
    r"""Fields for identifying an authorized individual."""

    first_name: Annotated[str, pydantic.Field(alias="firstName")]

    last_name: Annotated[str, pydantic.Field(alias="lastName")]


try:
    AuthorizedUser.model_rebuild()
except NameError:
    pass
