"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class DebitHoldPeriod(str, Enum):
    r"""An optional override of your default ACH hold period in banking days. The hold period must be longer than or equal to your default setting."""

    NO_HOLD = "no-hold"
    ONE_MINUS_DAY = "1-day"
    TWO_MINUS_DAYS = "2-days"
