"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .reversedwithcancellation import (
    ReversedWithCancellation,
    ReversedWithCancellationTypedDict,
)
from .reversedwithrefund import ReversedWithRefund, ReversedWithRefundTypedDict
from typing import Union
from typing_extensions import TypeAliasType


ReversalTypedDict = TypeAliasType(
    "ReversalTypedDict",
    Union[ReversedWithCancellationTypedDict, ReversedWithRefundTypedDict],
)
r"""Contains either a cancellation or refund, depending on the method used to reverse the transfer."""


Reversal = TypeAliasType(
    "Reversal", Union[ReversedWithCancellation, ReversedWithRefund]
)
r"""Contains either a cancellation or refund, depending on the method used to reverse the transfer."""
