"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel
from typing_extensions import TypedDict


class ItemListNextPageTypedDict(TypedDict):
    cursor: str
    r"""The cursor value to use for the next page of items."""


class ItemListNextPage(BaseModel):
    cursor: str
    r"""The cursor value to use for the next page of items."""
