"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .transactionsource import TransactionSource
from moovio_sdk.types import BaseModel, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class CreateTransferSourceCardTypedDict(TypedDict):
    dynamic_descriptor: NotRequired[str]
    r"""An optional override of the default card statement descriptor for a transfer. Accounts must be enabled by Moov to set this field."""
    transaction_source: NotRequired[TransactionSource]
    r"""Specifies the nature and initiator of a transaction.

    Crucial for recurring and merchant-initiated transactions as per card scheme rules.
    Omit for customer-initiated e-commerce transactions.
    """


class CreateTransferSourceCard(BaseModel):
    dynamic_descriptor: Annotated[
        Optional[str], pydantic.Field(alias="dynamicDescriptor")
    ] = None
    r"""An optional override of the default card statement descriptor for a transfer. Accounts must be enabled by Moov to set this field."""

    transaction_source: Annotated[
        Optional[TransactionSource], pydantic.Field(alias="transactionSource")
    ] = None
    r"""Specifies the nature and initiator of a transaction.

    Crucial for recurring and merchant-initiated transactions as per card scheme rules.
    Omit for customer-initiated e-commerce transactions.
    """

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["dynamicDescriptor", "transactionSource"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    CreateTransferSourceCard.model_rebuild()
except NameError:
    pass
