"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .amountdecimal import AmountDecimal, AmountDecimalTypedDict
from moovio_sdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class BillingSummaryInterchangeTypedDict(TypedDict):
    r"""A summary of interchange fees by card brand."""

    visa: AmountDecimalTypedDict
    r"""Total interchange fees for Visa."""
    mastercard: AmountDecimalTypedDict
    r"""Total interchange fees for Mastercard."""
    discover: AmountDecimalTypedDict
    r"""Total interchange fees for Discover."""
    american_express: AmountDecimalTypedDict
    r"""Total interchange fees for American Express."""


class BillingSummaryInterchange(BaseModel):
    r"""A summary of interchange fees by card brand."""

    visa: AmountDecimal
    r"""Total interchange fees for Visa."""

    mastercard: AmountDecimal
    r"""Total interchange fees for Mastercard."""

    discover: AmountDecimal
    r"""Total interchange fees for Discover."""

    american_express: Annotated[AmountDecimal, pydantic.Field(alias="americanExpress")]
    r"""Total interchange fees for American Express."""


try:
    BillingSummaryInterchange.model_rebuild()
except NameError:
    pass
