"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class Mode(str, Enum):
    r"""The operating mode for an account."""

    SANDBOX = "sandbox"
    PRODUCTION = "production"
