"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class CreateRefundTypedDict(TypedDict):
    r"""Specifies a partial amount to refund.

    This request body is optional, an empty body will issue a refund for the full amount of the original transfer.
    """

    amount: NotRequired[int]
    r"""Amount to refund in cents. If null, the original transfer's full amount will be refunded."""


class CreateRefund(BaseModel):
    r"""Specifies a partial amount to refund.

    This request body is optional, an empty body will issue a refund for the full amount of the original transfer.
    """

    amount: Optional[int] = None
    r"""Amount to refund in cents. If null, the original transfer's full amount will be refunded."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["amount"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
