"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .cardtransactionfailurecode import CardTransactionFailureCode
from .refundcardstatus import RefundCardStatus
from datetime import datetime
from moovio_sdk.types import BaseModel, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class RefundCardDetailsTypedDict(TypedDict):
    status: RefundCardStatus
    failure_code: NotRequired[CardTransactionFailureCode]
    initiated_on: NotRequired[datetime]
    confirmed_on: NotRequired[datetime]
    settled_on: NotRequired[datetime]
    failed_on: NotRequired[datetime]
    completed_on: NotRequired[datetime]


class RefundCardDetails(BaseModel):
    status: RefundCardStatus

    failure_code: Annotated[
        Optional[CardTransactionFailureCode], pydantic.Field(alias="failureCode")
    ] = None

    initiated_on: Annotated[Optional[datetime], pydantic.Field(alias="initiatedOn")] = (
        None
    )

    confirmed_on: Annotated[Optional[datetime], pydantic.Field(alias="confirmedOn")] = (
        None
    )

    settled_on: Annotated[Optional[datetime], pydantic.Field(alias="settledOn")] = None

    failed_on: Annotated[Optional[datetime], pydantic.Field(alias="failedOn")] = None

    completed_on: Annotated[Optional[datetime], pydantic.Field(alias="completedOn")] = (
        None
    )

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "failureCode",
                "initiatedOn",
                "confirmedOn",
                "settledOn",
                "failedOn",
                "completedOn",
            ]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    RefundCardDetails.model_rebuild()
except NameError:
    pass
