"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel
from typing_extensions import TypedDict


class BrandColorTypedDict(TypedDict):
    accent: str
    r"""A CSS hex color representing an accent color."""


class BrandColor(BaseModel):
    accent: str
    r"""A CSS hex color representing an accent color."""
