"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .accountnameverification import (
    AccountNameVerification,
    AccountNameVerificationTypedDict,
)
from .cardverificationresult import CardVerificationResult
from moovio_sdk.types import BaseModel, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class CardVerificationTypedDict(TypedDict):
    r"""The results of submitting cardholder data to a card network for verification."""

    cvv: CardVerificationResult
    address_line1: CardVerificationResult
    postal_code: CardVerificationResult
    account_name: NotRequired[AccountNameVerificationTypedDict]
    r"""The results of submitting cardholder name to a card network for verification."""


class CardVerification(BaseModel):
    r"""The results of submitting cardholder data to a card network for verification."""

    cvv: CardVerificationResult

    address_line1: Annotated[
        CardVerificationResult, pydantic.Field(alias="addressLine1")
    ]

    postal_code: Annotated[CardVerificationResult, pydantic.Field(alias="postalCode")]

    account_name: Annotated[
        Optional[AccountNameVerification], pydantic.Field(alias="accountName")
    ] = None
    r"""The results of submitting cardholder name to a card network for verification."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["accountName"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    CardVerification.model_rebuild()
except NameError:
    pass
