"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class WebhookTransferPaymentMethodDetailsTypedDict(TypedDict):
    r"""Payment method details for the source or destination of a transfer."""

    account_id: str
    payment_method_id: str


class WebhookTransferPaymentMethodDetails(BaseModel):
    r"""Payment method details for the source or destination of a transfer."""

    account_id: Annotated[str, pydantic.Field(alias="accountID")]

    payment_method_id: Annotated[str, pydantic.Field(alias="paymentMethodID")]


try:
    WebhookTransferPaymentMethodDetails.model_rebuild()
except NameError:
    pass
