"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .terminalapplicationstatus import TerminalApplicationStatus
from moovio_sdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class WebhookDataTerminalApplicationCreatedTypedDict(TypedDict):
    terminal_application_id: str
    status: TerminalApplicationStatus
    r"""Status of the terminal application."""


class WebhookDataTerminalApplicationCreated(BaseModel):
    terminal_application_id: Annotated[
        str, pydantic.Field(alias="terminalApplicationID")
    ]

    status: TerminalApplicationStatus
    r"""Status of the terminal application."""


try:
    WebhookDataTerminalApplicationCreated.model_rebuild()
except NameError:
    pass
