"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class MonthlyVolumeRange(str, Enum):
    r"""The low value in each range is included. The high value in each range is excluded."""

    UNDER_10K = "under-10k"
    TENK_50K = "10k-50k"
    FIFTYK_100K = "50k-100k"
    ONE_HUNDREDK_250K = "100k-250k"
    TWO_HUNDRED_AND_FIFTYK_500K = "250k-500k"
    FIVE_HUNDREDK_1M = "500k-1m"
    ONEM_5M = "1m-5m"
    OVER_5M = "over-5m"
