"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class SECCode(str, Enum):
    r"""Code used to identify the ACH authorization method."""

    WEB = "WEB"
    PPD = "PPD"
    CCD = "CCD"
    TEL = "TEL"
