"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class PaymentLinkStatus(str, Enum):
    ACTIVE = "active"
    USED = "used"
    DISABLED = "disabled"
    EXPIRED = "expired"
