"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class BankAccountHolderType(str, Enum):
    r"""The type of holder on a funding source."""

    INDIVIDUAL = "individual"
    BUSINESS = "business"
    GUEST = "guest"
