"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class UpdateIssuedCardState(str, Enum):
    r"""Updates the state of a Moov issued card.
    - `closed`: The card is permanently deactivated and cannot approve authorizations. A card can be closed by request or when it expires.
    """

    CLOSED = "closed"
