"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class IssuedCardEventType(str, Enum):
    r"""The type of event that occurred on the card."""

    AUTHORIZATION = "authorization"
    REVERSAL = "reversal"
    AUTHORIZATION_ADVICE = "authorization-advice"
    AUTHORIZATION_EXPIRATION = "authorization-expiration"
    AUTHORIZATION_INCREMENTAL = "authorization-incremental"
    CLEARING = "clearing"
