"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from moovio_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
import pydantic
from pydantic import model_serializer
from typing_extensions import Annotated, NotRequired, TypedDict


class Status(str, Enum):
    ENABLED = "enabled"
    DISABLED = "disabled"


class PatchSweepConfigTypedDict(TypedDict):
    status: NotRequired[Nullable[Status]]
    push_payment_method_id: NotRequired[Nullable[str]]
    pull_payment_method_id: NotRequired[Nullable[str]]
    statement_descriptor: NotRequired[Nullable[str]]
    minimum_balance: NotRequired[Nullable[str]]


class PatchSweepConfig(BaseModel):
    status: OptionalNullable[Status] = UNSET

    push_payment_method_id: Annotated[
        OptionalNullable[str], pydantic.Field(alias="pushPaymentMethodID")
    ] = UNSET

    pull_payment_method_id: Annotated[
        OptionalNullable[str], pydantic.Field(alias="pullPaymentMethodID")
    ] = UNSET

    statement_descriptor: Annotated[
        OptionalNullable[str], pydantic.Field(alias="statementDescriptor")
    ] = UNSET

    minimum_balance: Annotated[
        OptionalNullable[str], pydantic.Field(alias="minimumBalance")
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "status",
                "pushPaymentMethodID",
                "pullPaymentMethodID",
                "statementDescriptor",
                "minimumBalance",
            ]
        )
        nullable_fields = set(
            [
                "status",
                "pushPaymentMethodID",
                "pullPaymentMethodID",
                "statementDescriptor",
                "minimumBalance",
            ]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


try:
    PatchSweepConfig.model_rebuild()
except NameError:
    pass
