"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class EventTypeTypedDict(TypedDict):
    r"""Describes an available event type that can be subscribed to."""

    event_type_id: str
    r"""Unique identifier for the event type."""
    type: str
    r"""The type identifier string."""
    description: str
    r"""A human-readable description of the event type."""


class EventType(BaseModel):
    r"""Describes an available event type that can be subscribed to."""

    event_type_id: Annotated[str, pydantic.Field(alias="eventTypeID")]
    r"""Unique identifier for the event type."""

    type: str
    r"""The type identifier string."""

    description: str
    r"""A human-readable description of the event type."""


try:
    EventType.model_rebuild()
except NameError:
    pass
