"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel
from typing_extensions import TypedDict


class TermsOfServiceTokenTypedDict(TypedDict):
    r"""An encrypted value used to record acceptance of Moov's Terms of Service."""

    token: str


class TermsOfServiceToken(BaseModel):
    r"""An encrypted value used to record acceptance of Moov's Terms of Service."""

    token: str
