"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .brandcolors import BrandColors, BrandColorsTypedDict
from moovio_sdk.types import BaseModel
from typing_extensions import TypedDict


class BrandPropertiesTypedDict(TypedDict):
    colors: BrandColorsTypedDict
    r"""Brand colors for light and dark modes."""


class BrandProperties(BaseModel):
    colors: BrandColors
    r"""Brand colors for light and dark modes."""
