"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class IssuingIntervalLimit(str, Enum):
    r"""Specifies the time frame for the velocity limit. Currently supports only per-transaction limits."""

    PER_TRANSACTION = "per-transaction"
