"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class TransactionSource(str, Enum):
    r"""Specifies the nature and initiator of a transaction.

    Crucial for recurring and merchant-initiated transactions as per card scheme rules.
    Omit for customer-initiated e-commerce transactions.
    """

    FIRST_RECURRING = "first-recurring"
    RECURRING = "recurring"
    UNSCHEDULED = "unscheduled"
