"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class FeeCategory(str, Enum):
    ACH = "ach"
    CARD_ACQUIRING = "card-acquiring"
    CARD_OTHER = "card-other"
    CARD_PULL = "card-pull"
    CARD_PUSH = "card-push"
    INSTANT_BANK = "instant-bank"
    MONTHLY_PLATFORM = "monthly-platform"
    NETWORK_PASSTHROUGH = "network-passthrough"
    OTHER = "other"
    RTP = "rtp"
