"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel
from typing_extensions import TypedDict


class TerminalConfigurationTypedDict(TypedDict):
    r"""Describes a terminal configuration."""

    configuration: str


class TerminalConfiguration(BaseModel):
    r"""Describes a terminal configuration."""

    configuration: str
