"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .bankaccountexception import BankAccountException, BankAccountExceptionTypedDict
from .bankaccountverificationmethod import BankAccountVerificationMethod
from .bankaccountverificationstatus import BankAccountVerificationStatus
from moovio_sdk.types import BaseModel, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class BankAccountVerificationTypedDict(TypedDict):
    verification_method: BankAccountVerificationMethod
    status: BankAccountVerificationStatus
    exception_details: NotRequired[BankAccountExceptionTypedDict]
    r"""Reason for, and details related to, an `errored` or `verificationFailed` bank account status."""


class BankAccountVerification(BaseModel):
    verification_method: Annotated[
        BankAccountVerificationMethod, pydantic.Field(alias="verificationMethod")
    ]

    status: BankAccountVerificationStatus

    exception_details: Annotated[
        Optional[BankAccountException], pydantic.Field(alias="exceptionDetails")
    ] = None
    r"""Reason for, and details related to, an `errored` or `verificationFailed` bank account status."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["exceptionDetails"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    BankAccountVerification.model_rebuild()
except NameError:
    pass
