"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .webhookbillingstatementcreated import (
    WebhookBillingStatementCreated,
    WebhookBillingStatementCreatedTypedDict,
)
from .webhookdataaccountcreated import (
    WebhookDataAccountCreated,
    WebhookDataAccountCreatedTypedDict,
)
from .webhookdataaccountdisconnected import (
    WebhookDataAccountDisconnected,
    WebhookDataAccountDisconnectedTypedDict,
)
from .webhookdataaccountupdated import (
    WebhookDataAccountUpdated,
    WebhookDataAccountUpdatedTypedDict,
)
from .webhookdatabalanceupdated import (
    WebhookDataBalanceUpdated,
    WebhookDataBalanceUpdatedTypedDict,
)
from .webhookdatabankaccountcreated import (
    WebhookDataBankAccountCreated,
    WebhookDataBankAccountCreatedTypedDict,
)
from .webhookdatabankaccountdeleted import (
    WebhookDataBankAccountDeleted,
    WebhookDataBankAccountDeletedTypedDict,
)
from .webhookdatabankaccountupdated import (
    WebhookDataBankAccountUpdated,
    WebhookDataBankAccountUpdatedTypedDict,
)
from .webhookdatacancellationcreated import (
    WebhookDataCancellationCreated,
    WebhookDataCancellationCreatedTypedDict,
)
from .webhookdatacancellationupdated import (
    WebhookDataCancellationUpdated,
    WebhookDataCancellationUpdatedTypedDict,
)
from .webhookdatacapabilityrequested import (
    WebhookDataCapabilityRequested,
    WebhookDataCapabilityRequestedTypedDict,
)
from .webhookdatacapabilityupdated import (
    WebhookDataCapabilityUpdated,
    WebhookDataCapabilityUpdatedTypedDict,
)
from .webhookdatacardautoupdated import (
    WebhookDataCardAutoUpdated,
    WebhookDataCardAutoUpdatedTypedDict,
)
from .webhookdatadisputecreated import (
    WebhookDataDisputeCreated,
    WebhookDataDisputeCreatedTypedDict,
)
from .webhookdatadisputeupdated import (
    WebhookDataDisputeUpdated,
    WebhookDataDisputeUpdatedTypedDict,
)
from .webhookdatainvoicecreated import (
    WebhookDataInvoiceCreated,
    WebhookDataInvoiceCreatedTypedDict,
)
from .webhookdatainvoiceupdated import (
    WebhookDataInvoiceUpdated,
    WebhookDataInvoiceUpdatedTypedDict,
)
from .webhookdatanetworkidupdated import (
    WebhookDataNetworkIDUpdated,
    WebhookDataNetworkIDUpdatedTypedDict,
)
from .webhookdatapaymentmethoddisabled import (
    WebhookDataPaymentMethodDisabled,
    WebhookDataPaymentMethodDisabledTypedDict,
)
from .webhookdatapaymentmethodenabled import (
    WebhookDataPaymentMethodEnabled,
    WebhookDataPaymentMethodEnabledTypedDict,
)
from .webhookdatarefundcreated import (
    WebhookDataRefundCreated,
    WebhookDataRefundCreatedTypedDict,
)
from .webhookdatarefundupdated import (
    WebhookDataRefundUpdated,
    WebhookDataRefundUpdatedTypedDict,
)
from .webhookdatarepresentativecreated import (
    WebhookDataRepresentativeCreated,
    WebhookDataRepresentativeCreatedTypedDict,
)
from .webhookdatarepresentativedisabled import (
    WebhookDataRepresentativeDisabled,
    WebhookDataRepresentativeDisabledTypedDict,
)
from .webhookdatarepresentativeupdated import (
    WebhookDataRepresentativeUpdated,
    WebhookDataRepresentativeUpdatedTypedDict,
)
from .webhookdatasweepcreated import (
    WebhookDataSweepCreated,
    WebhookDataSweepCreatedTypedDict,
)
from .webhookdatasweepupdated import (
    WebhookDataSweepUpdated,
    WebhookDataSweepUpdatedTypedDict,
)
from .webhookdataterminalapplicationcreated import (
    WebhookDataTerminalApplicationCreated,
    WebhookDataTerminalApplicationCreatedTypedDict,
)
from .webhookdataterminalapplicationupdated import (
    WebhookDataTerminalApplicationUpdated,
    WebhookDataTerminalApplicationUpdatedTypedDict,
)
from .webhookdataticketcreated import (
    WebhookDataTicketCreated,
    WebhookDataTicketCreatedTypedDict,
)
from .webhookdataticketmessageadded import (
    WebhookDataTicketMessageAdded,
    WebhookDataTicketMessageAddedTypedDict,
)
from .webhookdataticketupdated import (
    WebhookDataTicketUpdated,
    WebhookDataTicketUpdatedTypedDict,
)
from .webhookdatatransfercreated import (
    WebhookDataTransferCreated,
    WebhookDataTransferCreatedTypedDict,
)
from .webhookdatatransferupdated import (
    WebhookDataTransferUpdated,
    WebhookDataTransferUpdatedTypedDict,
)
from .webhookdatawalletcreated import (
    WebhookDataWalletCreated,
    WebhookDataWalletCreatedTypedDict,
)
from .webhookdatawallettransactionupdated import (
    WebhookDataWalletTransactionUpdated,
    WebhookDataWalletTransactionUpdatedTypedDict,
)
from .webhookdatawalletupdated import (
    WebhookDataWalletUpdated,
    WebhookDataWalletUpdatedTypedDict,
)
from typing import Union
from typing_extensions import TypeAliasType


WebhookDataTypedDict = TypeAliasType(
    "WebhookDataTypedDict",
    Union[
        WebhookBillingStatementCreatedTypedDict,
        WebhookDataBankAccountDeletedTypedDict,
        WebhookDataTerminalApplicationUpdatedTypedDict,
        WebhookDataBalanceUpdatedTypedDict,
        WebhookDataBankAccountCreatedTypedDict,
        WebhookDataAccountUpdatedTypedDict,
        WebhookDataRepresentativeCreatedTypedDict,
        WebhookDataWalletCreatedTypedDict,
        WebhookDataAccountDisconnectedTypedDict,
        WebhookDataAccountCreatedTypedDict,
        WebhookDataTerminalApplicationCreatedTypedDict,
        WebhookDataSweepCreatedTypedDict,
        WebhookDataRepresentativeDisabledTypedDict,
        WebhookDataRepresentativeUpdatedTypedDict,
        WebhookDataInvoiceCreatedTypedDict,
        WebhookDataCardAutoUpdatedTypedDict,
        WebhookDataCapabilityRequestedTypedDict,
        WebhookDataPaymentMethodEnabledTypedDict,
        WebhookDataPaymentMethodDisabledTypedDict,
        WebhookDataRefundCreatedTypedDict,
        WebhookDataWalletUpdatedTypedDict,
        WebhookDataInvoiceUpdatedTypedDict,
        WebhookDataCancellationCreatedTypedDict,
        WebhookDataTicketMessageAddedTypedDict,
        WebhookDataTicketCreatedTypedDict,
        WebhookDataCancellationUpdatedTypedDict,
        WebhookDataSweepUpdatedTypedDict,
        WebhookDataCapabilityUpdatedTypedDict,
        WebhookDataTicketUpdatedTypedDict,
        WebhookDataTransferCreatedTypedDict,
        WebhookDataRefundUpdatedTypedDict,
        WebhookDataWalletTransactionUpdatedTypedDict,
        WebhookDataBankAccountUpdatedTypedDict,
        WebhookDataNetworkIDUpdatedTypedDict,
        WebhookDataDisputeCreatedTypedDict,
        WebhookDataTransferUpdatedTypedDict,
        WebhookDataDisputeUpdatedTypedDict,
    ],
)
r"""The data for the webhook event. The contents are based on the event type."""


WebhookData = TypeAliasType(
    "WebhookData",
    Union[
        WebhookBillingStatementCreated,
        WebhookDataBankAccountDeleted,
        WebhookDataTerminalApplicationUpdated,
        WebhookDataBalanceUpdated,
        WebhookDataBankAccountCreated,
        WebhookDataAccountUpdated,
        WebhookDataRepresentativeCreated,
        WebhookDataWalletCreated,
        WebhookDataAccountDisconnected,
        WebhookDataAccountCreated,
        WebhookDataTerminalApplicationCreated,
        WebhookDataSweepCreated,
        WebhookDataRepresentativeDisabled,
        WebhookDataRepresentativeUpdated,
        WebhookDataInvoiceCreated,
        WebhookDataCardAutoUpdated,
        WebhookDataCapabilityRequested,
        WebhookDataPaymentMethodEnabled,
        WebhookDataPaymentMethodDisabled,
        WebhookDataRefundCreated,
        WebhookDataWalletUpdated,
        WebhookDataInvoiceUpdated,
        WebhookDataCancellationCreated,
        WebhookDataTicketMessageAdded,
        WebhookDataTicketCreated,
        WebhookDataCancellationUpdated,
        WebhookDataSweepUpdated,
        WebhookDataCapabilityUpdated,
        WebhookDataTicketUpdated,
        WebhookDataTransferCreated,
        WebhookDataRefundUpdated,
        WebhookDataWalletTransactionUpdated,
        WebhookDataBankAccountUpdated,
        WebhookDataNetworkIDUpdated,
        WebhookDataDisputeCreated,
        WebhookDataTransferUpdated,
        WebhookDataDisputeUpdated,
    ],
)
r"""The data for the webhook event. The contents are based on the event type."""
