"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from moovio_sdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class TicketMessageTypedDict(TypedDict):
    author: str
    body: str
    sent_on: datetime


class TicketMessage(BaseModel):
    author: str

    body: str

    sent_on: Annotated[datetime, pydantic.Field(alias="sentOn")]


try:
    TicketMessage.model_rebuild()
except NameError:
    pass
