"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class IssuingAuthorizationStatus(str, Enum):
    r"""Status of a card issuing authorization."""

    PENDING = "pending"
    DECLINED = "declined"
    CANCELED = "canceled"
    CLEARED = "cleared"
    EXPIRED = "expired"
