"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

import importlib.metadata

__title__: str = "moovio_sdk"
__version__: str = "0.0.0-dev.6"
__openapi_doc_version__: str = "dev"
__gen_version__: str = "2.856.1"
__user_agent__: str = "speakeasy-sdk/python 0.0.0-dev.6 2.856.1 dev moovio_sdk"

try:
    if __package__ is not None:
        __version__ = importlib.metadata.version(__package__)
except importlib.metadata.PackageNotFoundError:
    pass
