"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class EstimatedActivityErrorTypedDict(TypedDict):
    average_transaction_amount: NotRequired[str]
    maximum_transaction_amount: NotRequired[str]
    monthly_volume_range: NotRequired[str]


class EstimatedActivityError(BaseModel):
    average_transaction_amount: Annotated[
        Optional[str], pydantic.Field(alias="averageTransactionAmount")
    ] = None

    maximum_transaction_amount: Annotated[
        Optional[str], pydantic.Field(alias="maximumTransactionAmount")
    ] = None

    monthly_volume_range: Annotated[
        Optional[str], pydantic.Field(alias="monthlyVolumeRange")
    ] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "averageTransactionAmount",
                "maximumTransactionAmount",
                "monthlyVolumeRange",
            ]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    EstimatedActivityError.model_rebuild()
except NameError:
    pass
