"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .evidencetype import EvidenceType
from datetime import datetime
from moovio_sdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class EvidenceTextResponseTypedDict(TypedDict):
    evidence_id: str
    dispute_id: str
    evidence_type: EvidenceType
    text: str
    created_on: datetime


class EvidenceTextResponse(BaseModel):
    evidence_id: Annotated[str, pydantic.Field(alias="evidenceID")]

    dispute_id: Annotated[str, pydantic.Field(alias="disputeID")]

    evidence_type: Annotated[EvidenceType, pydantic.Field(alias="evidenceType")]

    text: str

    created_on: Annotated[datetime, pydantic.Field(alias="createdOn")]


try:
    EvidenceTextResponse.model_rebuild()
except NameError:
    pass
