"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class CardPaymentTypedDict(TypedDict):
    statement_descriptor: NotRequired[str]


class CardPayment(BaseModel):
    statement_descriptor: Annotated[
        Optional[str], pydantic.Field(alias="statementDescriptor")
    ] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["statementDescriptor"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class AchPaymentTypedDict(TypedDict):
    company_name: NotRequired[str]


class AchPayment(BaseModel):
    company_name: Annotated[Optional[str], pydantic.Field(alias="companyName")] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["companyName"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class CreateAccountSettingsTypedDict(TypedDict):
    card_payment: NotRequired[CardPaymentTypedDict]
    ach_payment: NotRequired[AchPaymentTypedDict]


class CreateAccountSettings(BaseModel):
    card_payment: Annotated[
        Optional[CardPayment], pydantic.Field(alias="cardPayment")
    ] = None

    ach_payment: Annotated[Optional[AchPayment], pydantic.Field(alias="achPayment")] = (
        None
    )

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["cardPayment", "achPayment"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    CardPayment.model_rebuild()
except NameError:
    pass
try:
    AchPayment.model_rebuild()
except NameError:
    pass
try:
    CreateAccountSettings.model_rebuild()
except NameError:
    pass
