"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class TransferParty(str, Enum):
    SOURCE = "source"
    DESTINATION = "destination"
    PARTNER = "partner"
