"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
import httpx
from moovio_sdk.models.errors import MoovError
from moovio_sdk.types import BaseModel
import pydantic
from typing import Optional
from typing_extensions import Annotated


class UpdateWebhookValidationErrorData(BaseModel):
    url: Optional[str] = None
    r"""Details about the URL validation error."""
    status: Optional[str] = None
    r"""Details about the status validation error."""
    event_types: Annotated[Optional[str], pydantic.Field(alias="eventTypes")] = None
    r"""Details about the event types validation error."""
    description: Optional[str] = None
    r"""Details about the description validation error."""


@dataclass(unsafe_hash=True)
class UpdateWebhookValidationError(MoovError):
    data: UpdateWebhookValidationErrorData = field(hash=False)

    def __init__(
        self,
        data: UpdateWebhookValidationErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)
