"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .achpaymentdetailserror import (
    ACHPaymentDetailsError,
    ACHPaymentDetailsErrorTypedDict,
)
from .cardpaymentdetailserror import (
    CardPaymentDetailsError,
    CardPaymentDetailsErrorTypedDict,
)
from moovio_sdk.types import BaseModel, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class PaymentDetailsErrorTypedDict(TypedDict):
    allowed_methods: NotRequired[str]
    card_details: NotRequired[CardPaymentDetailsErrorTypedDict]
    ach_details: NotRequired[ACHPaymentDetailsErrorTypedDict]
    metadata: NotRequired[str]


class PaymentDetailsError(BaseModel):
    allowed_methods: Annotated[
        Optional[str], pydantic.Field(alias="allowedMethods")
    ] = None

    card_details: Annotated[
        Optional[CardPaymentDetailsError], pydantic.Field(alias="cardDetails")
    ] = None

    ach_details: Annotated[
        Optional[ACHPaymentDetailsError], pydantic.Field(alias="achDetails")
    ] = None

    metadata: Optional[str] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            ["allowedMethods", "cardDetails", "achDetails", "metadata"]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    PaymentDetailsError.model_rebuild()
except NameError:
    pass
