"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class FeeModel(str, Enum):
    r"""Specifies the pricing model used for the calculation of the final fee."""

    FIXED = "fixed"
    BLENDED = "blended"
    VARIABLE = "variable"
