"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class CardAcquiringModel(str, Enum):
    r"""Specifies the card processing pricing model"""

    COST_PLUS = "cost-plus"
    FLAT_RATE = "flat-rate"
