"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .invoicestatus import InvoiceStatus
from moovio_sdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class WebhookDataInvoiceUpdatedTypedDict(TypedDict):
    account_id: str
    invoice_id: str
    status: InvoiceStatus


class WebhookDataInvoiceUpdated(BaseModel):
    account_id: Annotated[str, pydantic.Field(alias="accountID")]

    invoice_id: Annotated[str, pydantic.Field(alias="invoiceID")]

    status: InvoiceStatus


try:
    WebhookDataInvoiceUpdated.model_rebuild()
except NameError:
    pass
