"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class InstantBankTransactionStatus(str, Enum):
    r"""Status of a transaction within the instant-bank lifecycle."""

    INITIATED = "initiated"
    COMPLETED = "completed"
    FAILED = "failed"
    ACCEPTED_WITHOUT_POSTING = "accepted-without-posting"
