"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .paymentmethodswallet import PaymentMethodsWallet, PaymentMethodsWalletTypedDict
from enum import Enum
from moovio_sdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class MoovWalletPaymentMethodPaymentMethodType(str, Enum):
    MOOV_WALLET = "moov-wallet"


class MoovWalletPaymentMethodTypedDict(TypedDict):
    payment_method_id: str
    r"""ID of the payment method."""
    payment_method_type: MoovWalletPaymentMethodPaymentMethodType
    wallet: PaymentMethodsWalletTypedDict


class MoovWalletPaymentMethod(BaseModel):
    payment_method_id: Annotated[str, pydantic.Field(alias="paymentMethodID")]
    r"""ID of the payment method."""

    payment_method_type: Annotated[
        MoovWalletPaymentMethodPaymentMethodType,
        pydantic.Field(alias="paymentMethodType"),
    ]

    wallet: PaymentMethodsWallet


try:
    MoovWalletPaymentMethod.model_rebuild()
except NameError:
    pass
