"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class CardTransactionStatus(str, Enum):
    r"""Status of a transaction within the card payment lifecycle."""

    INITIATED = "initiated"
    CONFIRMED = "confirmed"
    CANCELED = "canceled"
    SETTLED = "settled"
    FAILED = "failed"
    COMPLETED = "completed"
