"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .mooverror import MoovError
from typing import Any, TYPE_CHECKING

from moovio_sdk.utils.dynamic_imports import lazy_getattr, lazy_dir

if TYPE_CHECKING:
    from .accountterminalapplicationerror import (
        AccountTerminalApplicationError,
        AccountTerminalApplicationErrorData,
    )
    from .addcapabilitieserror import AddCapabilitiesError, AddCapabilitiesErrorData
    from .apierror import APIError
    from .assigncountrieserror import AssignCountriesError, AssignCountriesErrorData
    from .authtokenrequesterror import AuthTokenRequestError, AuthTokenRequestErrorData
    from .bankaccountvalidationerror import (
        BankAccountValidationError,
        BankAccountValidationErrorData,
    )
    from .brandvalidationerror import BrandValidationError, BrandValidationErrorData
    from .cardacquiringrefund import CardAcquiringRefund, CardAcquiringRefundData
    from .connectaccountrequestvalidationerror import (
        ConnectAccountRequestValidationError,
        ConnectAccountRequestValidationErrorData,
    )
    from .createaccounterror import CreateAccountError, CreateAccountErrorData
    from .createinvoiceerror import CreateInvoiceError, CreateInvoiceErrorData
    from .createinvoicepaymenterror import (
        CreateInvoicePaymentError,
        CreateInvoicePaymentErrorData,
    )
    from .createpaymentlinkerror import (
        CreatePaymentLinkError,
        CreatePaymentLinkErrorData,
    )
    from .createsweepconfigerror import (
        CreateSweepConfigError,
        CreateSweepConfigErrorData,
    )
    from .createticketerror import CreateTicketError, CreateTicketErrorData
    from .createwalletvalidationerror import (
        CreateWalletValidationError,
        CreateWalletValidationErrorData,
    )
    from .createwebhookvalidationerror import (
        CreateWebhookValidationError,
        CreateWebhookValidationErrorData,
    )
    from .duplicatecarderror import DuplicateCardError, DuplicateCardErrorData
    from .feeplanagreementerror import FeePlanAgreementError, FeePlanAgreementErrorData
    from .fileuploadvalidationerror import (
        File,
        FileTypedDict,
        FileUploadValidationError,
        FileUploadValidationErrorData,
    )
    from .filevalidationerror import FileValidationError, FileValidationErrorData
    from .genericerror import GenericError, GenericErrorData
    from .imagemetadatavalidationerror import (
        ImageMetadataValidationError,
        ImageMetadataValidationErrorData,
    )
    from .imagerequestvalidationerror import (
        ImageRequestValidationError,
        ImageRequestValidationErrorData,
    )
    from .linkapplepayerror import LinkApplePayError, LinkApplePayErrorData
    from .linkcarderror import LinkCardError, LinkCardErrorData
    from .listinvoicesvalidationerror import (
        ListInvoicesValidationError,
        ListInvoicesValidationErrorData,
    )
    from .listtransfersvalidationerror import (
        ListTransfersValidationError,
        ListTransfersValidationErrorData,
    )
    from .listwalletsvalidationerror import (
        ListWalletsValidationError,
        ListWalletsValidationErrorData,
    )
    from .listwallettransactionsvalidationerror import (
        ListWalletTransactionsValidationError,
        ListWalletTransactionsValidationErrorData,
    )
    from .microdepositvalidationerror import (
        MicroDepositValidationError,
        MicroDepositValidationErrorData,
    )
    from .no_response_error import NoResponseError
    from .onboardinginviteerror import OnboardingInviteError, OnboardingInviteErrorData
    from .patchaccounterror import PatchAccountError, PatchAccountErrorData
    from .patchsweepconfigerror import PatchSweepConfigError, PatchSweepConfigErrorData
    from .patchtransfervalidationerror import (
        PatchTransferValidationError,
        PatchTransferValidationErrorData,
    )
    from .patchwalletvalidationerror import (
        PatchWalletValidationError,
        PatchWalletValidationErrorData,
    )
    from .productrequestvalidationerror import (
        ProductRequestValidationError,
        ProductRequestValidationErrorData,
    )
    from .refundvalidationerror import RefundValidationError, RefundValidationErrorData
    from .representativevalidationerror import (
        Error,
        ErrorTypedDict,
        RepresentativeValidationError,
        RepresentativeValidationErrorData,
    )
    from .requestcarderror import RequestCardError, RequestCardErrorData
    from .responsevalidationerror import ResponseValidationError
    from .reversalvalidationerror import (
        ReversalValidationError,
        ReversalValidationErrorData,
    )
    from .revoketokenrequesterror import (
        RevokeTokenRequestError,
        RevokeTokenRequestErrorData,
    )
    from .schedulevalidationerror import (
        ScheduleValidationError,
        ScheduleValidationErrorData,
    )
    from .terminalapplicationerror import (
        TerminalApplicationError,
        TerminalApplicationErrorData,
    )
    from .transfer import Transfer, TransferData
    from .transferoptionsvalidationerror import (
        TransferOptionsValidationError,
        TransferOptionsValidationErrorData,
    )
    from .transfervalidationerror import (
        TransferValidationError,
        TransferValidationErrorData,
    )
    from .updatecarderror import UpdateCardError, UpdateCardErrorData
    from .updateinvoiceerror import UpdateInvoiceError, UpdateInvoiceErrorData
    from .updateissuedcarderror import UpdateIssuedCardError, UpdateIssuedCardErrorData
    from .updatepaymentlinkerror import (
        UpdatePaymentLinkError,
        UpdatePaymentLinkErrorData,
    )
    from .updateticketerror import UpdateTicketError, UpdateTicketErrorData
    from .updateunderwritingerror import (
        UpdateUnderwritingError,
        UpdateUnderwritingErrorData,
        UpdateUnderwritingErrorError,
        UpdateUnderwritingErrorErrorTypedDict,
    )
    from .updatewebhookvalidationerror import (
        UpdateWebhookValidationError,
        UpdateWebhookValidationErrorData,
    )
    from .upsertunderwritingerror import (
        UpsertUnderwritingError,
        UpsertUnderwritingErrorData,
    )

__all__ = [
    "APIError",
    "AccountTerminalApplicationError",
    "AccountTerminalApplicationErrorData",
    "AddCapabilitiesError",
    "AddCapabilitiesErrorData",
    "AssignCountriesError",
    "AssignCountriesErrorData",
    "AuthTokenRequestError",
    "AuthTokenRequestErrorData",
    "BankAccountValidationError",
    "BankAccountValidationErrorData",
    "BrandValidationError",
    "BrandValidationErrorData",
    "CardAcquiringRefund",
    "CardAcquiringRefundData",
    "ConnectAccountRequestValidationError",
    "ConnectAccountRequestValidationErrorData",
    "CreateAccountError",
    "CreateAccountErrorData",
    "CreateInvoiceError",
    "CreateInvoiceErrorData",
    "CreateInvoicePaymentError",
    "CreateInvoicePaymentErrorData",
    "CreatePaymentLinkError",
    "CreatePaymentLinkErrorData",
    "CreateSweepConfigError",
    "CreateSweepConfigErrorData",
    "CreateTicketError",
    "CreateTicketErrorData",
    "CreateWalletValidationError",
    "CreateWalletValidationErrorData",
    "CreateWebhookValidationError",
    "CreateWebhookValidationErrorData",
    "DuplicateCardError",
    "DuplicateCardErrorData",
    "Error",
    "ErrorTypedDict",
    "FeePlanAgreementError",
    "FeePlanAgreementErrorData",
    "File",
    "FileTypedDict",
    "FileUploadValidationError",
    "FileUploadValidationErrorData",
    "FileValidationError",
    "FileValidationErrorData",
    "GenericError",
    "GenericErrorData",
    "ImageMetadataValidationError",
    "ImageMetadataValidationErrorData",
    "ImageRequestValidationError",
    "ImageRequestValidationErrorData",
    "LinkApplePayError",
    "LinkApplePayErrorData",
    "LinkCardError",
    "LinkCardErrorData",
    "ListInvoicesValidationError",
    "ListInvoicesValidationErrorData",
    "ListTransfersValidationError",
    "ListTransfersValidationErrorData",
    "ListWalletTransactionsValidationError",
    "ListWalletTransactionsValidationErrorData",
    "ListWalletsValidationError",
    "ListWalletsValidationErrorData",
    "MicroDepositValidationError",
    "MicroDepositValidationErrorData",
    "MoovError",
    "NoResponseError",
    "OnboardingInviteError",
    "OnboardingInviteErrorData",
    "PatchAccountError",
    "PatchAccountErrorData",
    "PatchSweepConfigError",
    "PatchSweepConfigErrorData",
    "PatchTransferValidationError",
    "PatchTransferValidationErrorData",
    "PatchWalletValidationError",
    "PatchWalletValidationErrorData",
    "ProductRequestValidationError",
    "ProductRequestValidationErrorData",
    "RefundValidationError",
    "RefundValidationErrorData",
    "RepresentativeValidationError",
    "RepresentativeValidationErrorData",
    "RequestCardError",
    "RequestCardErrorData",
    "ResponseValidationError",
    "ReversalValidationError",
    "ReversalValidationErrorData",
    "RevokeTokenRequestError",
    "RevokeTokenRequestErrorData",
    "ScheduleValidationError",
    "ScheduleValidationErrorData",
    "TerminalApplicationError",
    "TerminalApplicationErrorData",
    "Transfer",
    "TransferData",
    "TransferOptionsValidationError",
    "TransferOptionsValidationErrorData",
    "TransferValidationError",
    "TransferValidationErrorData",
    "UpdateCardError",
    "UpdateCardErrorData",
    "UpdateInvoiceError",
    "UpdateInvoiceErrorData",
    "UpdateIssuedCardError",
    "UpdateIssuedCardErrorData",
    "UpdatePaymentLinkError",
    "UpdatePaymentLinkErrorData",
    "UpdateTicketError",
    "UpdateTicketErrorData",
    "UpdateUnderwritingError",
    "UpdateUnderwritingErrorData",
    "UpdateUnderwritingErrorError",
    "UpdateUnderwritingErrorErrorTypedDict",
    "UpdateWebhookValidationError",
    "UpdateWebhookValidationErrorData",
    "UpsertUnderwritingError",
    "UpsertUnderwritingErrorData",
]

_dynamic_imports: dict[str, str] = {
    "AccountTerminalApplicationError": ".accountterminalapplicationerror",
    "AccountTerminalApplicationErrorData": ".accountterminalapplicationerror",
    "AddCapabilitiesError": ".addcapabilitieserror",
    "AddCapabilitiesErrorData": ".addcapabilitieserror",
    "APIError": ".apierror",
    "AssignCountriesError": ".assigncountrieserror",
    "AssignCountriesErrorData": ".assigncountrieserror",
    "AuthTokenRequestError": ".authtokenrequesterror",
    "AuthTokenRequestErrorData": ".authtokenrequesterror",
    "BankAccountValidationError": ".bankaccountvalidationerror",
    "BankAccountValidationErrorData": ".bankaccountvalidationerror",
    "BrandValidationError": ".brandvalidationerror",
    "BrandValidationErrorData": ".brandvalidationerror",
    "CardAcquiringRefund": ".cardacquiringrefund",
    "CardAcquiringRefundData": ".cardacquiringrefund",
    "ConnectAccountRequestValidationError": ".connectaccountrequestvalidationerror",
    "ConnectAccountRequestValidationErrorData": ".connectaccountrequestvalidationerror",
    "CreateAccountError": ".createaccounterror",
    "CreateAccountErrorData": ".createaccounterror",
    "CreateInvoiceError": ".createinvoiceerror",
    "CreateInvoiceErrorData": ".createinvoiceerror",
    "CreateInvoicePaymentError": ".createinvoicepaymenterror",
    "CreateInvoicePaymentErrorData": ".createinvoicepaymenterror",
    "CreatePaymentLinkError": ".createpaymentlinkerror",
    "CreatePaymentLinkErrorData": ".createpaymentlinkerror",
    "CreateSweepConfigError": ".createsweepconfigerror",
    "CreateSweepConfigErrorData": ".createsweepconfigerror",
    "CreateTicketError": ".createticketerror",
    "CreateTicketErrorData": ".createticketerror",
    "CreateWalletValidationError": ".createwalletvalidationerror",
    "CreateWalletValidationErrorData": ".createwalletvalidationerror",
    "CreateWebhookValidationError": ".createwebhookvalidationerror",
    "CreateWebhookValidationErrorData": ".createwebhookvalidationerror",
    "DuplicateCardError": ".duplicatecarderror",
    "DuplicateCardErrorData": ".duplicatecarderror",
    "FeePlanAgreementError": ".feeplanagreementerror",
    "FeePlanAgreementErrorData": ".feeplanagreementerror",
    "File": ".fileuploadvalidationerror",
    "FileTypedDict": ".fileuploadvalidationerror",
    "FileUploadValidationError": ".fileuploadvalidationerror",
    "FileUploadValidationErrorData": ".fileuploadvalidationerror",
    "FileValidationError": ".filevalidationerror",
    "FileValidationErrorData": ".filevalidationerror",
    "GenericError": ".genericerror",
    "GenericErrorData": ".genericerror",
    "ImageMetadataValidationError": ".imagemetadatavalidationerror",
    "ImageMetadataValidationErrorData": ".imagemetadatavalidationerror",
    "ImageRequestValidationError": ".imagerequestvalidationerror",
    "ImageRequestValidationErrorData": ".imagerequestvalidationerror",
    "LinkApplePayError": ".linkapplepayerror",
    "LinkApplePayErrorData": ".linkapplepayerror",
    "LinkCardError": ".linkcarderror",
    "LinkCardErrorData": ".linkcarderror",
    "ListInvoicesValidationError": ".listinvoicesvalidationerror",
    "ListInvoicesValidationErrorData": ".listinvoicesvalidationerror",
    "ListTransfersValidationError": ".listtransfersvalidationerror",
    "ListTransfersValidationErrorData": ".listtransfersvalidationerror",
    "ListWalletsValidationError": ".listwalletsvalidationerror",
    "ListWalletsValidationErrorData": ".listwalletsvalidationerror",
    "ListWalletTransactionsValidationError": ".listwallettransactionsvalidationerror",
    "ListWalletTransactionsValidationErrorData": ".listwallettransactionsvalidationerror",
    "MicroDepositValidationError": ".microdepositvalidationerror",
    "MicroDepositValidationErrorData": ".microdepositvalidationerror",
    "NoResponseError": ".no_response_error",
    "OnboardingInviteError": ".onboardinginviteerror",
    "OnboardingInviteErrorData": ".onboardinginviteerror",
    "PatchAccountError": ".patchaccounterror",
    "PatchAccountErrorData": ".patchaccounterror",
    "PatchSweepConfigError": ".patchsweepconfigerror",
    "PatchSweepConfigErrorData": ".patchsweepconfigerror",
    "PatchTransferValidationError": ".patchtransfervalidationerror",
    "PatchTransferValidationErrorData": ".patchtransfervalidationerror",
    "PatchWalletValidationError": ".patchwalletvalidationerror",
    "PatchWalletValidationErrorData": ".patchwalletvalidationerror",
    "ProductRequestValidationError": ".productrequestvalidationerror",
    "ProductRequestValidationErrorData": ".productrequestvalidationerror",
    "RefundValidationError": ".refundvalidationerror",
    "RefundValidationErrorData": ".refundvalidationerror",
    "Error": ".representativevalidationerror",
    "ErrorTypedDict": ".representativevalidationerror",
    "RepresentativeValidationError": ".representativevalidationerror",
    "RepresentativeValidationErrorData": ".representativevalidationerror",
    "RequestCardError": ".requestcarderror",
    "RequestCardErrorData": ".requestcarderror",
    "ResponseValidationError": ".responsevalidationerror",
    "ReversalValidationError": ".reversalvalidationerror",
    "ReversalValidationErrorData": ".reversalvalidationerror",
    "RevokeTokenRequestError": ".revoketokenrequesterror",
    "RevokeTokenRequestErrorData": ".revoketokenrequesterror",
    "ScheduleValidationError": ".schedulevalidationerror",
    "ScheduleValidationErrorData": ".schedulevalidationerror",
    "TerminalApplicationError": ".terminalapplicationerror",
    "TerminalApplicationErrorData": ".terminalapplicationerror",
    "Transfer": ".transfer",
    "TransferData": ".transfer",
    "TransferOptionsValidationError": ".transferoptionsvalidationerror",
    "TransferOptionsValidationErrorData": ".transferoptionsvalidationerror",
    "TransferValidationError": ".transfervalidationerror",
    "TransferValidationErrorData": ".transfervalidationerror",
    "UpdateCardError": ".updatecarderror",
    "UpdateCardErrorData": ".updatecarderror",
    "UpdateInvoiceError": ".updateinvoiceerror",
    "UpdateInvoiceErrorData": ".updateinvoiceerror",
    "UpdateIssuedCardError": ".updateissuedcarderror",
    "UpdateIssuedCardErrorData": ".updateissuedcarderror",
    "UpdatePaymentLinkError": ".updatepaymentlinkerror",
    "UpdatePaymentLinkErrorData": ".updatepaymentlinkerror",
    "UpdateTicketError": ".updateticketerror",
    "UpdateTicketErrorData": ".updateticketerror",
    "UpdateUnderwritingError": ".updateunderwritingerror",
    "UpdateUnderwritingErrorData": ".updateunderwritingerror",
    "UpdateUnderwritingErrorError": ".updateunderwritingerror",
    "UpdateUnderwritingErrorErrorTypedDict": ".updateunderwritingerror",
    "UpdateWebhookValidationError": ".updatewebhookvalidationerror",
    "UpdateWebhookValidationErrorData": ".updatewebhookvalidationerror",
    "UpsertUnderwritingError": ".upsertunderwritingerror",
    "UpsertUnderwritingErrorData": ".upsertunderwritingerror",
}


def __getattr__(attr_name: str) -> Any:
    return lazy_getattr(
        attr_name, package=__package__, dynamic_imports=_dynamic_imports
    )


def __dir__():
    return lazy_dir(dynamic_imports=_dynamic_imports)
