"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .addresssuggestion import AddressSuggestion, AddressSuggestionTypedDict
from moovio_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class EnrichedAddressResponseTypedDict(TypedDict):
    suggestions: List[AddressSuggestionTypedDict]


class EnrichedAddressResponse(BaseModel):
    suggestions: List[AddressSuggestion]
