"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .amount import Amount, AmountTypedDict
from .sourcedestinationoptions import (
    SourceDestinationOptions,
    SourceDestinationOptionsTypedDict,
)
from moovio_sdk.types import BaseModel
from typing_extensions import TypedDict


class CreateTransferOptionsTypedDict(TypedDict):
    source: SourceDestinationOptionsTypedDict
    destination: SourceDestinationOptionsTypedDict
    amount: AmountTypedDict


class CreateTransferOptions(BaseModel):
    source: SourceDestinationOptions

    destination: SourceDestinationOptions

    amount: Amount
