"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class AccountTerminalApplicationTypedDict(TypedDict):
    r"""Describes link between an account and a terminal application."""

    account_id: str
    r"""ID of the merchant account."""
    terminal_application_id: str
    r"""ID of the terminal application."""


class AccountTerminalApplication(BaseModel):
    r"""Describes link between an account and a terminal application."""

    account_id: Annotated[str, pydantic.Field(alias="accountID")]
    r"""ID of the merchant account."""

    terminal_application_id: Annotated[
        str, pydantic.Field(alias="terminalApplicationID")
    ]
    r"""ID of the terminal application."""


try:
    AccountTerminalApplication.model_rebuild()
except NameError:
    pass
