"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel
from typing_extensions import TypedDict


class CardExpirationTypedDict(TypedDict):
    r"""The expiration date of the card or token."""

    month: str
    year: str


class CardExpiration(BaseModel):
    r"""The expiration date of the card or token."""

    month: str

    year: str
