"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .industrytaxonomy import IndustryTaxonomy, IndustryTaxonomyTypedDict
from moovio_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class EnrichedIndustriesTypedDict(TypedDict):
    industries: List[IndustryTaxonomyTypedDict]


class EnrichedIndustries(BaseModel):
    industries: List[IndustryTaxonomy]
