"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .brandcolor import BrandColor, BrandColorTypedDict
from moovio_sdk.types import BaseModel
from typing_extensions import TypedDict


class BrandColorsTypedDict(TypedDict):
    r"""Brand colors for light and dark modes."""

    dark: BrandColorTypedDict
    light: BrandColorTypedDict


class BrandColors(BaseModel):
    r"""Brand colors for light and dark modes."""

    dark: BrandColor

    light: BrandColor
