"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .productoptionvalidationerror import (
    ProductOptionValidationError,
    ProductOptionValidationErrorTypedDict,
)
from moovio_sdk.types import BaseModel, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import Dict, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ProductOptionGroupValidationErrorTypedDict(TypedDict):
    name: NotRequired[str]
    description: NotRequired[str]
    min_select: NotRequired[str]
    max_select: NotRequired[str]
    options: NotRequired[Dict[str, ProductOptionValidationErrorTypedDict]]


class ProductOptionGroupValidationError(BaseModel):
    name: Optional[str] = None

    description: Optional[str] = None

    min_select: Annotated[Optional[str], pydantic.Field(alias="minSelect")] = None

    max_select: Annotated[Optional[str], pydantic.Field(alias="maxSelect")] = None

    options: Optional[Dict[str, ProductOptionValidationError]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            ["name", "description", "minSelect", "maxSelect", "options"]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    ProductOptionGroupValidationError.model_rebuild()
except NameError:
    pass
