"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
import httpx
from moovio_sdk.models.errors import MoovError
from moovio_sdk.types import BaseModel
import pydantic
from typing import Optional
from typing_extensions import Annotated


class ListInvoicesValidationErrorData(BaseModel):
    status: Optional[str] = None
    customer_account_id: Annotated[
        Optional[str], pydantic.Field(alias="customerAccountID")
    ] = None
    created_start_date_time: Annotated[
        Optional[str], pydantic.Field(alias="createdStartDateTime")
    ] = None
    created_end_date_time: Annotated[
        Optional[str], pydantic.Field(alias="createdEndDateTime")
    ] = None
    due_start_date_time: Annotated[
        Optional[str], pydantic.Field(alias="dueStartDateTime")
    ] = None
    due_end_date_time: Annotated[
        Optional[str], pydantic.Field(alias="dueEndDateTime")
    ] = None
    skip: Optional[str] = None
    count: Optional[str] = None


@dataclass(unsafe_hash=True)
class ListInvoicesValidationError(MoovError):
    data: ListInvoicesValidationErrorData = field(hash=False)

    def __init__(
        self,
        data: ListInvoicesValidationErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)
