"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .scheduledtransferlineitem import (
    ScheduledTransferLineItem,
    ScheduledTransferLineItemTypedDict,
)
from moovio_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class ScheduledTransferLineItemsTypedDict(TypedDict):
    r"""Line items for a scheduled transfer."""

    items: List[ScheduledTransferLineItemTypedDict]
    r"""The list of line items."""


class ScheduledTransferLineItems(BaseModel):
    r"""Line items for a scheduled transfer."""

    items: List[ScheduledTransferLineItem]
    r"""The list of line items."""
