"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class BankAccountStatus(str, Enum):
    NEW = "new"
    VERIFIED = "verified"
    VERIFICATION_FAILED = "verificationFailed"
    PENDING = "pending"
    ERRORED = "errored"
