"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class TokenType(str, Enum):
    r"""An [RFC 6750](https://www.rfc-editor.org/rfc/rfc6750#section-6.1) token type."""

    BEARER = "Bearer"
