"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class PaymentMethodType(str, Enum):
    r"""The payment method type that represents a payment rail and directionality"""

    MOOV_WALLET = "moov-wallet"
    ACH_DEBIT_FUND = "ach-debit-fund"
    ACH_DEBIT_COLLECT = "ach-debit-collect"
    ACH_CREDIT_STANDARD = "ach-credit-standard"
    ACH_CREDIT_SAME_DAY = "ach-credit-same-day"
    RTP_CREDIT = "rtp-credit"
    CARD_PAYMENT = "card-payment"
    PUSH_TO_CARD = "push-to-card"
    PULL_FROM_CARD = "pull-from-card"
    APPLE_PAY = "apple-pay"
    CARD_PRESENT_PAYMENT = "card-present-payment"
    INSTANT_BANK_CREDIT = "instant-bank-credit"
