"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .phonenumber import PhoneNumber, PhoneNumberTypedDict
from moovio_sdk.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class GuestProfileTypedDict(TypedDict):
    r"""Describes a guest account profile."""

    name: str
    r"""The name associated with the guest account.
    This will default to \"Guest {accountIDfirst8}\" if no other name is provided.
    """
    phone: NotRequired[PhoneNumberTypedDict]
    email: NotRequired[str]


class GuestProfile(BaseModel):
    r"""Describes a guest account profile."""

    name: str
    r"""The name associated with the guest account.
    This will default to \"Guest {accountIDfirst8}\" if no other name is provided.
    """

    phone: Optional[PhoneNumber] = None

    email: Optional[str] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["phone", "email"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
