"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from moovio_sdk.types import BaseModel, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class WebhookDataNetworkIDUpdatedTypedDict(TypedDict):
    account_id: str
    visa_mid: NotRequired[str]
    mastercard_mid: NotRequired[str]
    discover_mid: NotRequired[str]
    amex_mid: NotRequired[str]
    updated_on: NotRequired[datetime]


class WebhookDataNetworkIDUpdated(BaseModel):
    account_id: Annotated[str, pydantic.Field(alias="accountID")]

    visa_mid: Annotated[Optional[str], pydantic.Field(alias="visaMid")] = None

    mastercard_mid: Annotated[Optional[str], pydantic.Field(alias="mastercardMid")] = (
        None
    )

    discover_mid: Annotated[Optional[str], pydantic.Field(alias="discoverMid")] = None

    amex_mid: Annotated[Optional[str], pydantic.Field(alias="amexMid")] = None

    updated_on: Annotated[Optional[datetime], pydantic.Field(alias="updatedOn")] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            ["visaMid", "mastercardMid", "discoverMid", "amexMid", "updatedOn"]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    WebhookDataNetworkIDUpdated.model_rebuild()
except NameError:
    pass
