"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class DisputeTransferDetailsTypedDict(TypedDict):
    transfer_id: str
    r"""The disputed transfer's ID."""


class DisputeTransferDetails(BaseModel):
    transfer_id: Annotated[str, pydantic.Field(alias="transferID")]
    r"""The disputed transfer's ID."""


try:
    DisputeTransferDetails.model_rebuild()
except NameError:
    pass
