"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .createtransferlineitem import (
    CreateTransferLineItem,
    CreateTransferLineItemTypedDict,
)
from moovio_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class CreateTransferLineItemsTypedDict(TypedDict):
    r"""An optional collection of line items for a transfer.
    When line items are provided, their total plus sales tax must equal the transfer amount.
    """

    items: List[CreateTransferLineItemTypedDict]
    r"""The list of line items."""


class CreateTransferLineItems(BaseModel):
    r"""An optional collection of line items for a transfer.
    When line items are provided, their total plus sales tax must equal the transfer amount.
    """

    items: List[CreateTransferLineItem]
    r"""The list of line items."""
