"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class PendingLitigation(str, Enum):
    BANKRUPTCY_OR_INSOLVENCY = "bankruptcy-or-insolvency"
    CONSUMER_PROTECTION_OR_CLASS_ACTION = "consumer-protection-or-class-action"
    DATA_BREACH_OR_PRIVACY = "data-breach-or-privacy"
    EMPLOYMENT_OR_WORKPLACE_DISPUTES = "employment-or-workplace-disputes"
    FRAUD_OR_FINANCIAL_CRIME = "fraud-or-financial-crime"
    GOVERNMENT_ENFORCEMENT_OR_INVESTIGATION = "government-enforcement-or-investigation"
    INTELLECTUAL_PROPERTY = "intellectual-property"
    NONE = "none"
    OTHER = "other"
    PERSONAL_INJURY_OR_MEDICAL = "personal-injury-or-medical"
