"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .rtpservices import RTPServices, RTPServicesTypedDict
from moovio_sdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class RTPInstitutionTypedDict(TypedDict):
    name: str
    r"""Name of the financial institution."""
    routing_number: str
    services: RTPServicesTypedDict


class RTPInstitution(BaseModel):
    name: str
    r"""Name of the financial institution."""

    routing_number: Annotated[str, pydantic.Field(alias="routingNumber")]

    services: RTPServices


try:
    RTPInstitution.model_rebuild()
except NameError:
    pass
