"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class DomesticPullFromCard(str, Enum):
    r"""Indicates if the card supports domestic pull-from-card transfer."""

    NOT_SUPPORTED = "not-supported"
    SUPPORTED = "supported"
    UNKNOWN = "unknown"
