"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel
from typing_extensions import TypedDict


class AccountCapabilityTypedDict(TypedDict):
    r"""Describes an action or set of actions that an account is permitted to perform."""

    capability: str
    status: str


class AccountCapability(BaseModel):
    r"""Describes an action or set of actions that an account is permitted to perform."""

    capability: str

    status: str
