"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
import httpx
from moovio_sdk.models.errors import MoovError
from moovio_sdk.types import BaseModel
import pydantic
from typing import Optional
from typing_extensions import Annotated


class DuplicateCardErrorData(BaseModel):
    error: str
    r"""A human-readable description of the error."""
    existing_card_id: Annotated[
        Optional[str], pydantic.Field(alias="existingCardID")
    ] = None
    r"""The ID of the existing card that caused the conflict.
    This field is included when attempting to link a card that already exists on the account.
    """


@dataclass(unsafe_hash=True)
class DuplicateCardError(MoovError):
    data: DuplicateCardErrorData = field(hash=False)

    def __init__(
        self,
        data: DuplicateCardErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)
