"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .invoicelineitem import InvoiceLineItem, InvoiceLineItemTypedDict
from moovio_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class InvoiceLineItemsTypedDict(TypedDict):
    r"""A collection of line items for an invoice."""

    items: List[InvoiceLineItemTypedDict]
    r"""The list of line items."""


class InvoiceLineItems(BaseModel):
    r"""A collection of line items for an invoice."""

    items: List[InvoiceLineItem]
    r"""The list of line items."""
