"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .createpaymentlinklineitem import (
    CreatePaymentLinkLineItem,
    CreatePaymentLinkLineItemTypedDict,
)
from moovio_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class CreatePaymentLinkLineItemsTypedDict(TypedDict):
    r"""An optional collection of line items for a payment link.
    When line items are provided, their total plus sales tax must equal the payment link amount.
    """

    items: List[CreatePaymentLinkLineItemTypedDict]
    r"""The list of line items."""


class CreatePaymentLinkLineItems(BaseModel):
    r"""An optional collection of line items for a payment link.
    When line items are provided, their total plus sales tax must equal the payment link amount.
    """

    items: List[CreatePaymentLinkLineItem]
    r"""The list of line items."""
