"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel
from typing_extensions import TypedDict


class CreateTransferACHAddendaRecordTypedDict(TypedDict):
    r"""An addenda record to be added to an ACH transfer"""

    record: str
    r"""The raw ACH addenda record. Must only contain valid NACHA characters"""


class CreateTransferACHAddendaRecord(BaseModel):
    r"""An addenda record to be added to an ACH transfer"""

    record: str
    r"""The raw ACH addenda record. Must only contain valid NACHA characters"""
