"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class CreateApplePaySessionTypedDict(TypedDict):
    domain: str
    r"""A fully qualified top-level or sub-domain name where you will accept Apple Pay. Should not include \"https\"."""
    display_name: str
    r"""A UTF-8 string to display in the Buy button."""


class CreateApplePaySession(BaseModel):
    domain: str
    r"""A fully qualified top-level or sub-domain name where you will accept Apple Pay. Should not include \"https\"."""

    display_name: Annotated[str, pydantic.Field(alias="displayName")]
    r"""A UTF-8 string to display in the Buy button."""


try:
    CreateApplePaySession.model_rebuild()
except NameError:
    pass
