"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class WebhookDataBankAccountCreatedTypedDict(TypedDict):
    bank_account_id: str
    account_id: str


class WebhookDataBankAccountCreated(BaseModel):
    bank_account_id: Annotated[str, pydantic.Field(alias="bankAccountID")]

    account_id: Annotated[str, pydantic.Field(alias="accountID")]


try:
    WebhookDataBankAccountCreated.model_rebuild()
except NameError:
    pass
