"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class BankAccountStatusReason(str, Enum):
    r"""The reason the bank account status changed to the current value."""

    BANK_ACCOUNT_CREATED = "bank-account-created"
    VERIFICATION_INITIATED = "verification-initiated"
    MICRO_DEPOSIT_ATTEMPTS_EXCEEDED = "micro-deposit-attempts-exceeded"
    MICRO_DEPOSIT_EXPIRED = "micro-deposit-expired"
    MAX_VERIFICATION_FAILURES = "max-verification-failures"
    VERIFICATION_ATTEMPTS_EXCEEDED = "verification-attempts-exceeded"
    VERIFICATION_EXPIRED = "verification-expired"
    VERIFICATION_SUCCESSFUL = "verification-successful"
    ACH_DEBIT_RETURN = "ach-debit-return"
    ACH_CREDIT_RETURN = "ach-credit-return"
    RTP_CREDIT_FAILURE = "rtp-credit-failure"
    FEDNOW_CREDIT_FAILURE = "fednow-credit-failure"
    MICRO_DEPOSIT_RETURN = "micro-deposit-return"
    ADMIN_ACTION = "admin-action"
    OTHER = "other"
