"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class BusinessType(str, Enum):
    r"""The type of entity represented by this business."""

    SOLE_PROPRIETORSHIP = "soleProprietorship"
    UNINCORPORATED_ASSOCIATION = "unincorporatedAssociation"
    TRUST = "trust"
    PUBLIC_CORPORATION = "publicCorporation"
    PRIVATE_CORPORATION = "privateCorporation"
    LLC = "llc"
    PARTNERSHIP = "partnership"
    UNINCORPORATED_NON_PROFIT = "unincorporatedNonProfit"
    INCORPORATED_NON_PROFIT = "incorporatedNonProfit"
    GOVERNMENT_ENTITY = "governmentEntity"
