"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .amountdecimal import AmountDecimal, AmountDecimalTypedDict
from datetime import datetime
from moovio_sdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class AdjustmentTypedDict(TypedDict):
    r"""An adjustment to a wallet."""

    adjustment_id: str
    wallet_id: str
    amount: AmountDecimalTypedDict
    created_on: datetime


class Adjustment(BaseModel):
    r"""An adjustment to a wallet."""

    adjustment_id: Annotated[str, pydantic.Field(alias="adjustmentID")]

    wallet_id: Annotated[str, pydantic.Field(alias="walletID")]

    amount: AmountDecimal

    created_on: Annotated[datetime, pydantic.Field(alias="createdOn")]


try:
    Adjustment.model_rebuild()
except NameError:
    pass
