"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
import httpx
from moovio_sdk.models.errors import MoovError
from moovio_sdk.types import BaseModel
import pydantic
from typing import Optional
from typing_extensions import Annotated


class TerminalApplicationErrorData(BaseModel):
    platform: Optional[str] = None
    app_bundle_id: Annotated[Optional[str], pydantic.Field(alias="appBundleID")] = None
    package_name: Annotated[Optional[str], pydantic.Field(alias="packageName")] = None
    sha256_digest: Annotated[Optional[str], pydantic.Field(alias="sha256Digest")] = None
    version_code: Annotated[Optional[str], pydantic.Field(alias="versionCode")] = None


@dataclass(unsafe_hash=True)
class TerminalApplicationError(MoovError):
    data: TerminalApplicationErrorData = field(hash=False)

    def __init__(
        self,
        data: TerminalApplicationErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)
