"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class CollectionPaymentMethodType(str, Enum):
    r"""Payment methods allowed for collecting a payment."""

    APPLE_PAY = "apple-pay"
    CARD_PAYMENT = "card-payment"
    ACH_DEBIT_COLLECT = "ach-debit-collect"
