"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class TransferACHAddendaRecordTypedDict(TypedDict):
    r"""An addenda record which was added to an ACH transfer"""

    record: str
    r"""The ACH addenda record, which may have masked PII"""
    is_masked: bool
    r"""Flag indicating whether or not this record has been masked"""


class TransferACHAddendaRecord(BaseModel):
    r"""An addenda record which was added to an ACH transfer"""

    record: str
    r"""The ACH addenda record, which may have masked PII"""

    is_masked: Annotated[bool, pydantic.Field(alias="isMasked")]
    r"""Flag indicating whether or not this record has been masked"""


try:
    TransferACHAddendaRecord.model_rebuild()
except NameError:
    pass
