"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class WebhookEventType(str, Enum):
    r"""The type of event that occurred."""

    WILDCARD_ = "*"
    ACCOUNT_CREATED = "account.created"
    ACCOUNT_UPDATED = "account.updated"
    ACCOUNT_DISCONNECTED = "account.disconnected"
    BALANCE_UPDATED = "balance.updated"
    BANK_ACCOUNT_CREATED = "bankAccount.created"
    BANK_ACCOUNT_UPDATED = "bankAccount.updated"
    BANK_ACCOUNT_DELETED = "bankAccount.deleted"
    CANCELLATION_CREATED = "cancellation.created"
    CANCELLATION_UPDATED = "cancellation.updated"
    CARD_AUTO_UPDATED = "card.autoUpdated"
    CAPABILITY_REQUESTED = "capability.requested"
    CAPABILITY_UPDATED = "capability.updated"
    DISPUTE_CREATED = "dispute.created"
    DISPUTE_UPDATED = "dispute.updated"
    INVOICE_CREATED = "invoice.created"
    INVOICE_UPDATED = "invoice.updated"
    NETWORK_ID_UPDATED = "networkID.updated"
    PAYMENT_METHOD_ENABLED = "paymentMethod.enabled"
    PAYMENT_METHOD_DISABLED = "paymentMethod.disabled"
    REFUND_CREATED = "refund.created"
    REFUND_UPDATED = "refund.updated"
    REPRESENTATIVE_CREATED = "representative.created"
    REPRESENTATIVE_UPDATED = "representative.updated"
    REPRESENTATIVE_DELETED = "representative.deleted"
    SWEEP_CREATED = "sweep.created"
    SWEEP_UPDATED = "sweep.updated"
    TERMINAL_APPLICATION_CREATED = "terminalApplication.created"
    TERMINAL_APPLICATION_UPDATED = "terminalApplication.updated"
    TICKET_CREATED = "ticket.created"
    TICKET_UPDATED = "ticket.updated"
    TICKET_MESSAGE_ADDED = "ticket.messageAdded"
    TRANSFER_CREATED = "transfer.created"
    TRANSFER_UPDATED = "transfer.updated"
    WALLET_CREATED = "wallet.created"
    WALLET_UPDATED = "wallet.updated"
    WALLET_TRANSACTION_UPDATED = "walletTransaction.updated"
    BILLING_STATEMENT_CREATED = "billingStatement.created"
