"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class TerminalApplicationPlatform(str, Enum):
    r"""Platform of the terminal application."""

    UNDEFINED = "undefined"
    IOS = "ios"
    ANDROID = "android"
