"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .issuingvelocitylimit import IssuingVelocityLimit, IssuingVelocityLimitTypedDict
from moovio_sdk.types import BaseModel, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class IssuingControlsTypedDict(TypedDict):
    single_use: NotRequired[bool]
    r"""Indicates if the card is single-use. If true, the card closes after the first authorization."""
    velocity_limits: NotRequired[List[IssuingVelocityLimitTypedDict]]
    r"""Sets the spending limit per time interval. Only one limit per interval is supported."""


class IssuingControls(BaseModel):
    single_use: Annotated[Optional[bool], pydantic.Field(alias="singleUse")] = None
    r"""Indicates if the card is single-use. If true, the card closes after the first authorization."""

    velocity_limits: Annotated[
        Optional[List[IssuingVelocityLimit]], pydantic.Field(alias="velocityLimits")
    ] = None
    r"""Sets the spending limit per time interval. Only one limit per interval is supported."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["singleUse", "velocityLimits"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    IssuingControls.model_rebuild()
except NameError:
    pass
