"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class DomesticPushToCard(str, Enum):
    r"""Indicates which level of domestic push-to-card transfer is supported by the card, if any."""

    NOT_SUPPORTED = "not-supported"
    STANDARD = "standard"
    FAST_FUNDS = "fast-funds"
    UNKNOWN = "unknown"
