"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .amount import Amount, AmountTypedDict
from datetime import datetime
from moovio_sdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class CardAcquiringDisputeTypedDict(TypedDict):
    r"""Details of a card dispute."""

    dispute_id: str
    created_on: datetime
    amount: AmountTypedDict


class CardAcquiringDispute(BaseModel):
    r"""Details of a card dispute."""

    dispute_id: Annotated[str, pydantic.Field(alias="disputeID")]

    created_on: Annotated[datetime, pydantic.Field(alias="createdOn")]

    amount: Amount


try:
    CardAcquiringDispute.model_rebuild()
except NameError:
    pass
