"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel
from typing_extensions import TypedDict


class CompleteBankAccountVerificationTypedDict(TypedDict):
    code: str
    r"""Code provided by user from their bank account transactions"""


class CompleteBankAccountVerification(BaseModel):
    code: str
    r"""Code provided by user from their bank account transactions"""
