"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class MonthlyPlatformFeeTypedDict(TypedDict):
    r"""Fixed recurring amount paid in the billing period regardless of usage."""

    currency: str
    r"""A 3-letter ISO 4217 currency code."""
    value_decimal: str
    r"""A decimal-formatted numerical string that represents up to 9 decimal place precision.

    For example, $12.987654321 is '12.987654321'.
    """


class MonthlyPlatformFee(BaseModel):
    r"""Fixed recurring amount paid in the billing period regardless of usage."""

    currency: str
    r"""A 3-letter ISO 4217 currency code."""

    value_decimal: Annotated[str, pydantic.Field(alias="valueDecimal")]
    r"""A decimal-formatted numerical string that represents up to 9 decimal place precision.

    For example, $12.987654321 is '12.987654321'.
    """


try:
    MonthlyPlatformFee.model_rebuild()
except NameError:
    pass
