"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class QRCodeTypedDict(TypedDict):
    qr_code: str
    r"""A base64-encoded PNG image of the QR code."""


class QRCode(BaseModel):
    qr_code: Annotated[str, pydantic.Field(alias="qrCode")]
    r"""A base64-encoded PNG image of the QR code."""


try:
    QRCode.model_rebuild()
except NameError:
    pass
