"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class CardVolumeDistributionTypedDict(TypedDict):
    ecommerce_percentage: int
    card_present_percentage: int
    mail_or_phone_percentage: int
    debt_repayment_percentage: int


class CardVolumeDistribution(BaseModel):
    ecommerce_percentage: Annotated[int, pydantic.Field(alias="ecommercePercentage")]

    card_present_percentage: Annotated[
        int, pydantic.Field(alias="cardPresentPercentage")
    ]

    mail_or_phone_percentage: Annotated[
        int, pydantic.Field(alias="mailOrPhonePercentage")
    ]

    debt_repayment_percentage: Annotated[
        int, pydantic.Field(alias="debtRepaymentPercentage")
    ]


try:
    CardVolumeDistribution.model_rebuild()
except NameError:
    pass
