"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .plaidintegration import PlaidIntegration, PlaidIntegrationTypedDict
from moovio_sdk.types import BaseModel
from typing_extensions import TypedDict


class PlaidPayloadTypedDict(TypedDict):
    r"""Describes the account to link to the Moov account using a Plaid processor token."""

    plaid: PlaidIntegrationTypedDict
    r"""The details of a Plaid processor integration for a linked funding source.

    `sandbox` - When linking a bank account to a `sandbox` account using a Plaid processor token a default bank account
    response will be used. The following default data will be used to generate the bank account in this flow:

    ```
    RoutingNumber: \"011401533\",
    AccountNumber: \"1111222233330000\",
    AccountType:   \"checking\",
    Mask:          \"0000\" 
    ```
    """


class PlaidPayload(BaseModel):
    r"""Describes the account to link to the Moov account using a Plaid processor token."""

    plaid: PlaidIntegration
    r"""The details of a Plaid processor integration for a linked funding source.

    `sandbox` - When linking a bank account to a `sandbox` account using a Plaid processor token a default bank account
    response will be used. The following default data will be used to generate the bank account in this flow:

    ```
    RoutingNumber: \"011401533\",
    AccountNumber: \"1111222233330000\",
    AccountType:   \"checking\",
    Mask:          \"0000\" 
    ```
    """
