"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class CardBrand(str, Enum):
    r"""The card brand."""

    AMERICAN_EXPRESS = "American Express"
    DISCOVER = "Discover"
    MASTERCARD = "Mastercard"
    VISA = "Visa"
    UNKNOWN = "Unknown"
