"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class WebhookDataTransferStatus(str, Enum):
    CREATED = "created"
    PENDING = "pending"
    COMPLETED = "completed"
    FAILED = "failed"
    REVERSED = "reversed"
    QUEUED = "queued"
    CANCELED = "canceled"
    SOURCE_COMPLETED = "source.completed"
    SOURCE_CORRECTED = "source.corrected"
    SOURCE_INITIATED = "source.initiated"
    SOURCE_RETURNED = "source.returned"
    SOURCE_ORIGINATED = "source.originated"
    SOURCE_CONFIRMED = "source.confirmed"
    SOURCE_SETTLED = "source.settled"
    SOURCE_FAILED = "source.failed"
    SOURCE_CANCELED = "source.canceled"
    DESTINATION_COMPLETED = "destination.completed"
    DESTINATION_CORRECTED = "destination.corrected"
    DESTINATION_INITIATED = "destination.initiated"
    DESTINATION_RETURNED = "destination.returned"
    DESTINATION_ORIGINATED = "destination.originated"
    DESTINATION_CONFIRMED = "destination.confirmed"
    DESTINATION_FAILED = "destination.failed"
    DESTINATION_ACCEPTED_WITHOUT_POSTING = "destination.accepted-without-posting"
