"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .cardupdatereason import CardUpdateReason
from moovio_sdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class WebhookDataCardAutoUpdatedTypedDict(TypedDict):
    card_id: str
    account_id: str
    update_type: CardUpdateReason
    r"""The results of the card update request."""


class WebhookDataCardAutoUpdated(BaseModel):
    card_id: Annotated[str, pydantic.Field(alias="cardID")]

    account_id: Annotated[str, pydantic.Field(alias="accountID")]

    update_type: Annotated[CardUpdateReason, pydantic.Field(alias="updateType")]
    r"""The results of the card update request."""


try:
    WebhookDataCardAutoUpdated.model_rebuild()
except NameError:
    pass
