"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel
from typing_extensions import TypedDict


class TerminalApplicationVersionTypedDict(TypedDict):
    r"""Describes a terminal application version."""

    version: str
    r"""The app version of the terminal application (version code for Android terminal application)."""


class TerminalApplicationVersion(BaseModel):
    r"""Describes a terminal application version."""

    version: str
    r"""The app version of the terminal application (version code for Android terminal application)."""
