"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class LinkAccountTerminalApplicationTypedDict(TypedDict):
    r"""Describes a request to link an account with a terminal application."""

    terminal_application_id: str
    r"""ID of the terminal application."""


class LinkAccountTerminalApplication(BaseModel):
    r"""Describes a request to link an account with a terminal application."""

    terminal_application_id: Annotated[
        str, pydantic.Field(alias="terminalApplicationID")
    ]
    r"""ID of the terminal application."""


try:
    LinkAccountTerminalApplication.model_rebuild()
except NameError:
    pass
