"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class IssuedCardAuthorizationEventResult(str, Enum):
    r"""The result of an event."""

    APPROVED = "approved"
    DECLINED = "declined"
    PROCESSED = "processed"
