"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class RefundPolicy(str, Enum):
    CONDITIONAL_REFUND = "conditional-refund"
    CUSTOM_POLICY = "custom-policy"
    EVENT_BASED_POLICY = "event-based-policy"
    FULL_REFUND_EXTENDED_WINDOW = "full-refund-extended-window"
    FULL_REFUND_WITHIN_30_DAYS = "full-refund-within-30-days"
    NO_REFUNDS = "no-refunds"
    PARTIAL_REFUND = "partial-refund"
    PRORATED_REFUND = "prorated-refund"
    STORE_CREDIT_ONLY = "store-credit-only"
