"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .walletstatus import WalletStatus
from moovio_sdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class WebhookDataWalletUpdatedTypedDict(TypedDict):
    account_id: str
    wallet_id: str
    status: WalletStatus
    r"""Status of a wallet.
    - `active`: The wallet is available for use and has an enabled payment method.
    - `closed`: The wallet is no longer active and the corresponding payment method has been disabled.
    """


class WebhookDataWalletUpdated(BaseModel):
    account_id: Annotated[str, pydantic.Field(alias="accountID")]

    wallet_id: Annotated[str, pydantic.Field(alias="walletID")]

    status: WalletStatus
    r"""Status of a wallet.
    - `active`: The wallet is available for use and has an enabled payment method.
    - `closed`: The wallet is no longer active and the corresponding payment method has been disabled.
    """


try:
    WebhookDataWalletUpdated.model_rebuild()
except NameError:
    pass
