"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class DisbursementPaymentMethodType(str, Enum):
    r"""Payment methods allowed for disbursing funds."""

    PUSH_TO_CARD = "push-to-card"
    RTP_CREDIT = "rtp-credit"
    ACH_CREDIT_SAME_DAY = "ach-credit-same-day"
    ACH_CREDIT_STANDARD = "ach-credit-standard"
