"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .issuingintervallimit import IssuingIntervalLimit
from moovio_sdk.types import BaseModel
from typing_extensions import TypedDict


class IssuingVelocityLimitTypedDict(TypedDict):
    amount: int
    r"""The maximum amount in cents that can be spent in a given interval."""
    interval: IssuingIntervalLimit
    r"""Specifies the time frame for the velocity limit. Currently supports only per-transaction limits."""


class IssuingVelocityLimit(BaseModel):
    amount: int
    r"""The maximum amount in cents that can be spent in a given interval."""

    interval: IssuingIntervalLimit
    r"""Specifies the time frame for the velocity limit. Currently supports only per-transaction limits."""
