"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class AchLocationTypedDict(TypedDict):
    address: str
    city: str
    postal_code: str
    postal_code_extension: str
    state: str


class AchLocation(BaseModel):
    address: str

    city: str

    postal_code: Annotated[str, pydantic.Field(alias="postalCode")]

    postal_code_extension: Annotated[str, pydantic.Field(alias="postalCodeExtension")]

    state: str


try:
    AchLocation.model_rebuild()
except NameError:
    pass
