"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from typing_extensions import deprecated


@deprecated(
    "warning: ** DEPRECATED ** - This will be removed in a future release, please migrate away from it as soon as possible."
)
class AccountVerificationStatus(str, Enum):
    r"""Possible states an account verification can be in."""

    UNVERIFIED = "unverified"
    PENDING = "pending"
    RESUBMIT = "resubmit"
    REVIEW = "review"
    VERIFIED = "verified"
    FAILED = "failed"
