"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class CompleteMicroDepositsTypedDict(TypedDict):
    r"""Request to complete the micro-deposit verification workflow."""

    amounts: List[int]
    r"""Two positive integers, in cents, equal to the values of the micro-deposits sent to the bank account."""


class CompleteMicroDeposits(BaseModel):
    r"""Request to complete the micro-deposit verification workflow."""

    amounts: List[int]
    r"""Two positive integers, in cents, equal to the values of the micro-deposits sent to the bank account."""
