"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .cancellationstatus import CancellationStatus
from datetime import datetime
from moovio_sdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class CancellationTypedDict(TypedDict):
    cancellation_id: str
    status: CancellationStatus
    created_on: datetime


class Cancellation(BaseModel):
    cancellation_id: Annotated[str, pydantic.Field(alias="cancellationID")]

    status: CancellationStatus

    created_on: Annotated[datetime, pydantic.Field(alias="createdOn")]


try:
    Cancellation.model_rebuild()
except NameError:
    pass
