"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from moovio_sdk.types import BaseModel
import pydantic
from typing import List
from typing_extensions import Annotated, TypedDict


class ApplePayMerchantDomainsTypedDict(TypedDict):
    account_id: str
    display_name: str
    r"""A UTF-8 string to display in the Buy button."""
    domains: List[str]
    r"""A unique list of fully-qualified, top-level or sub-domain names where you will accept Apple Pay."""
    created_on: datetime
    updated_on: datetime


class ApplePayMerchantDomains(BaseModel):
    account_id: Annotated[str, pydantic.Field(alias="accountID")]

    display_name: Annotated[str, pydantic.Field(alias="displayName")]
    r"""A UTF-8 string to display in the Buy button."""

    domains: List[str]
    r"""A unique list of fully-qualified, top-level or sub-domain names where you will accept Apple Pay."""

    created_on: Annotated[datetime, pydantic.Field(alias="createdOn")]

    updated_on: Annotated[datetime, pydantic.Field(alias="updatedOn")]


try:
    ApplePayMerchantDomains.model_rebuild()
except NameError:
    pass
