"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class FileStatus(str, Enum):
    r"""The file's status."""

    PENDING = "pending"
    APPROVED = "approved"
    REJECTED = "rejected"
