"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .transferpaymentmethodscard import (
    TransferPaymentMethodsCard,
    TransferPaymentMethodsCardTypedDict,
)
from enum import Enum
from moovio_sdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class PushToCardTransferPaymentMethodPaymentMethodType(str, Enum):
    PUSH_TO_CARD = "push-to-card"


class PushToCardTransferPaymentMethodTypedDict(TypedDict):
    payment_method_id: str
    r"""ID of the payment method."""
    payment_method_type: PushToCardTransferPaymentMethodPaymentMethodType
    card: TransferPaymentMethodsCardTypedDict
    r"""A card as contained within a payment method."""


class PushToCardTransferPaymentMethod(BaseModel):
    payment_method_id: Annotated[str, pydantic.Field(alias="paymentMethodID")]
    r"""ID of the payment method."""

    payment_method_type: Annotated[
        PushToCardTransferPaymentMethodPaymentMethodType,
        pydantic.Field(alias="paymentMethodType"),
    ]

    card: TransferPaymentMethodsCard
    r"""A card as contained within a payment method."""


try:
    PushToCardTransferPaymentMethod.model_rebuild()
except NameError:
    pass
