"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class AccountCountriesTypedDict(TypedDict):
    r"""The countries in which an account operates."""

    countries: List[str]


class AccountCountries(BaseModel):
    r"""The countries in which an account operates."""

    countries: List[str]
