"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class TicketStatus(str, Enum):
    NEW = "new"
    IN_PROGRESS = "in-progress"
    ON_HOLD = "on-hold"
    CLOSED = "closed"
