"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .cardupdatereason import CardUpdateReason
from datetime import datetime
from moovio_sdk.types import BaseModel, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class CardAccountUpdaterTypedDict(TypedDict):
    r"""The results of the most recent card update request."""

    updated_on: NotRequired[datetime]
    update_type: NotRequired[CardUpdateReason]
    r"""The results of the card update request."""


class CardAccountUpdater(BaseModel):
    r"""The results of the most recent card update request."""

    updated_on: Annotated[Optional[datetime], pydantic.Field(alias="updatedOn")] = None

    update_type: Annotated[
        Optional[CardUpdateReason], pydantic.Field(alias="updateType")
    ] = None
    r"""The results of the card update request."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["updatedOn", "updateType"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    CardAccountUpdater.model_rebuild()
except NameError:
    pass
