"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class WireServicesTypedDict(TypedDict):
    funds_transfer_status: bool
    r"""The institution's capability to process standard Fedwire funds transfers."""
    funds_settlement_only_status: bool
    r"""The institution's capability for settlement-only transfers."""
    book_entry_securities_transfer_status: bool
    r"""The institution's capability to handle transfers of securities."""


class WireServices(BaseModel):
    funds_transfer_status: Annotated[bool, pydantic.Field(alias="fundsTransferStatus")]
    r"""The institution's capability to process standard Fedwire funds transfers."""

    funds_settlement_only_status: Annotated[
        bool, pydantic.Field(alias="fundsSettlementOnlyStatus")
    ]
    r"""The institution's capability for settlement-only transfers."""

    book_entry_securities_transfer_status: Annotated[
        bool, pydantic.Field(alias="bookEntrySecuritiesTransferStatus")
    ]
    r"""The institution's capability to handle transfers of securities."""


try:
    WireServices.model_rebuild()
except NameError:
    pass
