"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class FulfillmentMethod(str, Enum):
    BILL_OR_DEBT_PAYMENT = "bill-or-debt-payment"
    DIGITAL_CONTENT = "digital-content"
    DONATION = "donation"
    IN_PERSON_SERVICE = "in-person-service"
    LOCAL_PICKUP_OR_DELIVERY = "local-pickup-or-delivery"
    OTHER = "other"
    REMOTE_SERVICE = "remote-service"
    SHIPPED_PHYSICAL_GOODS = "shipped-physical-goods"
    SUBSCRIPTION_OR_MEMBERSHIP = "subscription-or-membership"
