"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class CardVerificationResult(str, Enum):
    NO_MATCH = "noMatch"
    MATCH = "match"
    NOT_CHECKED = "notChecked"
    UNAVAILABLE = "unavailable"
    PARTIAL_MATCH = "partialMatch"
