"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class WebhookDataSweepCreatedTypedDict(TypedDict):
    wallet_id: str
    sweep_id: str


class WebhookDataSweepCreated(BaseModel):
    wallet_id: Annotated[str, pydantic.Field(alias="walletID")]

    sweep_id: Annotated[str, pydantic.Field(alias="sweepID")]


try:
    WebhookDataSweepCreated.model_rebuild()
except NameError:
    pass
