"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class BankAccountType(str, Enum):
    r"""The bank account type."""

    CHECKING = "checking"
    SAVINGS = "savings"
    GENERAL_LEDGER = "general-ledger"
    LOAN = "loan"
