"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class FedNowServicesTypedDict(TypedDict):
    receive_payments: bool
    r"""Indicates if the institution can receive instant payments."""
    send_payments: bool
    r"""Indicates if the institution can send instant payments."""
    request_for_payment: bool
    r"""Indicates if the institution can process request for payment messages."""


class FedNowServices(BaseModel):
    receive_payments: Annotated[bool, pydantic.Field(alias="receivePayments")]
    r"""Indicates if the institution can receive instant payments."""

    send_payments: Annotated[bool, pydantic.Field(alias="sendPayments")]
    r"""Indicates if the institution can send instant payments."""

    request_for_payment: Annotated[bool, pydantic.Field(alias="requestForPayment")]
    r"""Indicates if the institution can process request for payment messages."""


try:
    FedNowServices.model_rebuild()
except NameError:
    pass
