"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class InvoiceStatus(str, Enum):
    DRAFT = "draft"
    UNPAID = "unpaid"
    PAYMENT_PENDING = "payment-pending"
    PAID = "paid"
    OVERDUE = "overdue"
    CANCELED = "canceled"
