"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class IndividualNameUpdateTypedDict(TypedDict):
    first_name: NotRequired[str]
    r"""The individual's first given name."""
    middle_name: NotRequired[str]
    r"""The individual's second given name, if any."""
    last_name: NotRequired[str]
    r"""The individual's family name."""
    suffix: NotRequired[str]
    r"""Suffix of a given name."""


class IndividualNameUpdate(BaseModel):
    first_name: Annotated[Optional[str], pydantic.Field(alias="firstName")] = None
    r"""The individual's first given name."""

    middle_name: Annotated[Optional[str], pydantic.Field(alias="middleName")] = None
    r"""The individual's second given name, if any."""

    last_name: Annotated[Optional[str], pydantic.Field(alias="lastName")] = None
    r"""The individual's family name."""

    suffix: Optional[str] = None
    r"""Suffix of a given name."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["firstName", "middleName", "lastName", "suffix"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    IndividualNameUpdate.model_rebuild()
except NameError:
    pass
