"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class RTPServicesTypedDict(TypedDict):
    receive_payments: bool
    r"""Can the institution receive payments"""
    receive_request_for_payment: bool
    r"""Can the institution receive request for payment messages"""


class RTPServices(BaseModel):
    receive_payments: Annotated[bool, pydantic.Field(alias="receivePayments")]
    r"""Can the institution receive payments"""

    receive_request_for_payment: Annotated[
        bool, pydantic.Field(alias="receiveRequestForPayment")
    ]
    r"""Can the institution receive request for payment messages"""


try:
    RTPServices.model_rebuild()
except NameError:
    pass
