"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .bankaccountpayload import BankAccountPayload, BankAccountPayloadTypedDict
from .mxpayload import MxPayload, MxPayloadTypedDict
from .plaidlinkpayload import PlaidLinkPayload, PlaidLinkPayloadTypedDict
from .plaidpayload import PlaidPayload, PlaidPayloadTypedDict
from typing import Union
from typing_extensions import TypeAliasType


LinkBankAccountTypedDict = TypeAliasType(
    "LinkBankAccountTypedDict",
    Union[
        BankAccountPayloadTypedDict,
        PlaidPayloadTypedDict,
        PlaidLinkPayloadTypedDict,
        MxPayloadTypedDict,
    ],
)


LinkBankAccount = TypeAliasType(
    "LinkBankAccount",
    Union[BankAccountPayload, PlaidPayload, PlaidLinkPayload, MxPayload],
)
