"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class SweepStatus(str, Enum):
    ACCRUING = "accruing"
    ACTION_REQUIRED = "action-required"
    CANCELED = "canceled"
    CLOSED = "closed"
    FAILED = "failed"
    PAID = "paid"
