"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class WebhookBillingStatementCreatedTypedDict(TypedDict):
    statement_id: str


class WebhookBillingStatementCreated(BaseModel):
    statement_id: Annotated[str, pydantic.Field(alias="statementID")]


try:
    WebhookBillingStatementCreated.model_rebuild()
except NameError:
    pass
